*********************************************************************************
**Session: Creating
**Purpose: Creating the analysis sample
**Author:  Michele Ubaldi
**Date:    December 17, 2024
*********************************************************************************

clear all
set maxvar 32000

**COMMENT: Use the data file of kids and parents dataset
cd "C:\Users\your_folder_path\"
use  all_families_soepv36eu.dta, clear
xtset pidkid syear

**COMMENT: Create a balanced panel
**COMMENT: Fill in with missings if not in the panel
**COMMENT: Now everyone has observations from 1984 until 2019

drop _*
fillin pidkid syear
drop _*

**COMMENT: Now fill in time-invariant variables
sort pidkid syear
foreach var of varlist c_sex c_fnr c_mnr matchfather matchmother c_birthyear cid c_gebmonat {
	by pidkid: egen max`var' = max(`var')
	by pidkid: replace `var' = max`var' if `var'==.
	drop max`var'
}

by pidkid: replace c_age = syear - c_birthyear if c_age==.
bro pidkid c_birthyear syear c_age if c_age<0

***COMMENT: Create the specific binary indicator for sex
fre c_sex
gen fem = .
replace fem = 0 if c_sex==1
replace fem = 1 if c_sex==2
fre fem


/////////////////////////////////////////////////////////////////////////////////////////////////////////////////
**COMMENT: Keep only those born 1984 and later.
**Note: Count individuals and individuals-per year observations before and after the 1984 cut
*Before
xtdes
sum pidkid

keep if c_birthyear>=1984

*After
xtdes
sum pidkid

/////////////////////////////////////////////////////////////////////////////////////////////////////////////////
**COMMENT: For all variables, generate the values when the kids were 0-1 years old, etc. 
**         When the kid is 0 years old, we have to be careful
**COMMENT: You should make sure that the month of interview is AFTER the kid was borh 

bro pidkid syear c_age c_birthyea c_gebmonat c_pgmonth m_pgmonth f_pgmonth
by pidkid: replace c_pgmonth = m_pgmonth if  c_pgmonth==. & m_pgmonth!=. & pidmother!=.
by pidkid: replace c_pgmonth = f_pgmonth if  c_pgmonth==. & m_pgmonth==. & pidmother==. & f_pgmonth!=. & pidfather!=.

**COMMENT: Create birthyear dummies
tab c_birthyear, gen(d_birthyear)
rename d_birthyear1 by1984
label var by1984 "Birth year dummy: 1984"
rename d_birthyear2 by1985
label var by1985 "Birth year dummy: 1985"
rename d_birthyear3 by1986
label var by1986 "Birth year dummy: 1986"
rename d_birthyear4 by1987
label var by1987 "Birth year dummy: 1987"
rename d_birthyear5 by1988
label var by1988 "Birth year dummy: 1988"
rename d_birthyear6 by1989
label var by1989 "Birth year dummy: 1989"
rename d_birthyear7 by1990
label var by1990 "Birth year dummy: 1990"
rename d_birthyear8 by1991
label var by1991 "Birth year dummy: 1991"
rename d_birthyear9 by1992
label var by1992 "Birth year dummy: 1992"
rename d_birthyear10 by1993
label var by1993 "Birth year dummy: 1993"
rename d_birthyear11 by1994
label var by1994 "Birth year dummy: 1994"
rename d_birthyear12 by1995
label var by1995 "Birth year dummy: 1995"
rename d_birthyear13 by1996
label var by1996 "Birth year dummy: 1996"
rename d_birthyear14 by1997
label var by1997 "Birth year dummy: 1997"
rename d_birthyear15 by1998
label var by1998 "Birth year dummy: 1998"
rename d_birthyear16 by1999
label var by1999 "Birth year dummy: 1999"
rename d_birthyear17 by2000
label var by2000 "Birth year dummy: 2000"
rename d_birthyear18 by2001
label var by2001 "Birth year dummy: 2001"
rename d_birthyear19 by2002
label var by2002 "Birth year dummy: 2002"
rename d_birthyear20 by2005
label var by2005 "Birth year dummy: 2005"
rename d_birthyear21 by2007
label var by2007 "Birth year dummy: 2007"

********************************************************************************
******************** D E P E N D E N T   V A R I A B L E S  ********************
********************************************************************************

**********************************************************************
***Frequency of alcohol consumption
**********************************************************************

foreach var of varlist c_becon c_wicon c_spicon c_mixcon {
		by pidkid: gen rev_`var' = 5 -`var'
		label define rev_`var' 1 "Nie" 2 "Selten" 3 "Ab und zu" 4 "Regelmaessig"
		drop `var'
		rename rev_`var' `var'
}
by pidkid: gen alcohol = c_becon + c_wicon + c_spicon + c_mixcon

by pidkid: gen sevalcon = 1 if alco>=10
by pidkid: replace sevalcon = 0 if alco<10
by pidkid: replace sevalcon = . if alco==.

**********************************************************************
***Currently smoking
**********************************************************************

fre c_smoke
recode c_smoke 2=0
fre c_smoke

**********************************************************************
***Body-Mass Index, obesity, overweight and underweight probabilities
**********************************************************************
bys pidkid syear: gen bmi = c_weight/(c_height*0.01)^2

**Note: Check if you did a good work with the already cooked up vars
sum c_bmi bmi
cap drop c_bmi

bys pidkid syear: gen obese = 1 if bmi>=30 & bmi!=.
bys pidkid syear: replace obese = 0 if bmi<30 & bmi!=.

bys pidkid syear: gen ovwei = 1 if bmi>=25 & bmi!=.
bys pidkid syear: replace ovwei = 0 if bmi<25 & bmi!=.

bys pidkid syear: gen unwei = 1 if bmi<=25 & bmi!=.
bys pidkid syear: replace unwei = 0 if bmi>25 & bmi!=.

**********************************************************************
*** PCS and MCS indexes - from SF-12v2 SOEP (Nubling, 2006; Anderson, 2007)
**********************************************************************

*%%% PHYSICAL FUNCTIONING
clonevar c_hinstai1 = c_hinstai
rename c_hinstai1 hinstai
rename hinstai pfi02

clonevar c_tir1 = c_tir
rename c_tir1 tir
rename tir pfi04

*%%% ROLE PHYSICAL
clonevar c_lesswan_phy1 = c_lesswan_phy
rename c_lesswan_phy1 lesswan_phy
rename lesswan_phy rolph2

clonevar c_accomles_phy1 = c_accomles_phy
rename c_accomles_phy1 accomles_phy
rename accomles_phy rolph3

*%%% BODILY PAIN
clonevar c_phypain1 = c_phypain
rename c_phypain1 phypain
rename phypain pain2

*%%% GENERAL HEALTH
clonevar c_currhea1 = c_currhea
rename c_currhea1 currhea
rename currhea ghp1

*%%% VITALITY
clonevar c_energy1 = c_energy
rename c_energy1 energy
rename energy vital2

*%%% SOCIAL FUNTIONING
clonevar c_soclim1 = c_soclim
rename c_soclim1 soclim
rename soclim soc2

*%%% ROLE EMOTIONAL
clonevar c_accomles_men1 = c_accomles_men
rename c_accomles_men1 accomles_men
rename accomles_men rolem2

clonevar c_careless_men1 = c_careless_men
rename c_careless_men1 careless_men
rename careless_men rolem3

*%%% MENTAL HEALTH
clonevar c_rush1 = c_rush
rename c_rush1 rush
rename rush mhi1

clonevar c_mela1 = c_mela
rename c_mela1 mela
rename mela mhi4

clonevar c_relax1 = c_relax
rename c_relax1 relax
rename relax mhi3
		
qui bys pidkid: count if pfi02==. | pfi04==. | rolph2==. | rolph3==. | pain2==. | ghp1==. | vital2==. | soc2==. | rolem2==. | rolem3==. | mhi4==. | mhi3==.
bys pidkid: gen valid = 1 if pfi02!=. & pfi04!=. & rolph2!=. & rolph3!=. & pain2!=. & ghp1!=. & vital2!=. & soc2!=. & rolem2!=. & rolem3!=. & mhi4!=. & mhi3!=.
*PCS and MCS can be computed only for those whom do not present missing values in any of the 12 items

**Note: Rescale some vars so to that 5=most positive outcome for health, 1=worst possible outcome for health
gen rghp1 = (6 - ghp1)
gen rvital2 = (6 - vital2)
gen rmhi3 = (6 - mhi3)

**Note: Computing the means
egen mupf = rmean(pfi02 pfi04)
egen murp = rmean(rolph2 rolph3)
egen mure = rmean(rolem2 rolem3)
egen mumh = rmean(mhi4 rmhi3)
egen mubp = rmean(pain2)
egen mugh = rmean(rghp1)
egen muvt = rmean(rvital2)
egen musf = rmean(soc2)

**Note: Transforming the variables
gen pf100 = ((mupf-1)/2)*100 if valid==1		/* Physical functioning */
gen rp100 = ((murp-1)/4)*100 if valid==1		/* Role physical */
gen re100 = ((mure-1)/4)*100 if valid==1		/* Role emotional */
gen mh100 = ((mumh-1)/4)*100 if valid==1		/* Mental health */
gen bp100 = ((mubp-1)/4)*100 if valid==1		/* Bodily pain */
gen gh100 = ((mugh-1)/4)*100 if valid==1		/* General health */
gen vt100 = ((muvt-1)/4)*100 if valid==1		/* Vitality */
gen sf100 = ((musf-1)/4)*100 if valid==1		/* Social functioning */

label var mh100 "Mental health (0-100 score value, 3 vars)"
label var pf100 "Physical functioning (0-100 score value, 2 vars)"
label var rp100 "Role physical (0-100 score value, 2 vars)"
label var bp100 "Bodily pain (0-100 score value, 1 var)"
label var gh100 "General health (0-100 score value, 1 var)"
label var vt100 "Vitality (0-100 score value, 1 var)"
label var sf100 "Social functioning (0-100 score value, 1 var)"
label var re100 "Role emotional (0-100 score value, 2 vars)"

**Note: Transform values of the scales using mu and sd of SOEP04 norm population
gen pf_z = (pf100 - 73.14) / 32.15		/* Physical functioning */
gen rp_z = (rp100 - 74.29) / 26.46		/* Role physical */
gen bp_z = (bp100 - 73.27) / 27.14		/* Bodily pain */
gen gh_z = (gh100 - 60.57) / 24.08		/* General health */
gen vt_z = (vt100 - 52.94) / 22.84		/* Vitality */
gen sf_z = (sf100 - 83.22) / 23.57		/* Social functioning */
gen re_z = (re100 - 81.94) / 22.35		/* Role emotional */
gen mh_z = (mh100 - 61.96) / 20.47		/* Mental health */

**Note: Z-tranform the scales using norm based scoring (mean=50, sd=10)
gen pf_nbs = (pf_z*10)+50		/* Physical functioning */
gen rp_nbs = (rp_z*10)+50		/* Role physical */ 
gen bp_nbs = (bp_z*10)+50		/* Bodily pain */
gen gh_nbs = (gh_z*10)+50		/* General health */
gen vt_nbs = (vt_z*10)+50		/* Vitality */
gen sf_nbs = (sf_z*10)+50		/* Social functioning */
gen re_nbs = (re_z*10)+50		/* Role emotional */
gen mh_nbs = (mh_z*10)+50		/* Mental health */

label var pf_nbs "Physical functioning (NBS)"
label var rp_nbs "Role physical (NBS)"
label var bp_nbs "Bodily pain (NBS)"
label var gh_nbs "General health (NBS)"
label var vt_nbs "Vitality (NBS)"
label var sf_nbs "Social functioning (NBS)"
label var re_nbs "Role emotional (NBS)"
label var mh_nbs "Mental health (NBS)"
********************************************************************************

**Note: Building the superordinate scales PCS and MCS
gen agg_phys = (0.414*pf_z) + (0.279*rp_z) + (0.331*bp_z) + (0.330*gh_z) + (-0.041*vt_z) + (-0.068*sf_z) + (-0.110*re_z) + (-0.244*mh_z)
gen agg_ment = (-0.209*pf_z) + (-0.021*rp_z) + (-0.105*bp_z) + (-0.103*gh_z) + (0.258*vt_z) + (0.333*sf_z) + (0.378*re_z) + (0.489*mh_z)

gen pcs = (agg_phys*10)+50
gen mcs = (agg_ment*10)+50
label var pcs "PCS: Summary scale Physical (NBS)"
label var mcs "MCS: Summary scale Mental (NBS)"

**Note: Check if you did a good work with the already cooked up vars
sum c_mcs mcs
sum c_pcs pcs
cap drop c_mcs c_pcs


***TOPIC: Harmonization of job security questions***

* Up to 1998 it is coded on a 4-point scale (1 certain 2 probably 3 probably not 4 unlikely) only in even syears,
* After 1998 it is coded on 11-point prob. scale where 0 is 0% prob. and 10 is 100% prob.
table f_job_explose1 syear
table f_job_explose2 syear 
table m_job_explose1 syear
table m_job_explose2 syear

gen f_job_explose_rec = f_job_explose1 if syear<=1998
foreach var of varlist f_job_explose2 {
replace f_job_explose_rec = `var' if syear>=1999
* 1= unlikely (0%), 2=probably not (10-50%) 3=probable (60-90%) ; 4=cetrain (100%)
replace f_job_explose_rec = 4 if f_job_explose2==0 & syear>=1999
replace f_job_explose_rec = 3 if f_job_explose2>=10 & f_job_explose2<=50 & syear>=1999
replace f_job_explose_rec = 2 if f_job_explose2>=60 & f_job_explose2<=90 & syear>=1999
replace f_job_explose_rec = 1 if f_job_explose2==100 & syear>=1999
}

gen m_job_explose_rec = m_job_explose1 if syear<=1998
foreach var of varlist m_job_explose2 {
replace m_job_explose_rec = `var' if syear>=1999
* 1= unlikely (0%), 2=probably not (10-50%) 3=probable (60-90%) ; 4=cetrain (100%)
replace m_job_explose_rec = 4 if m_job_explose2==0 & syear>=1999
replace m_job_explose_rec = 3 if m_job_explose2>=10 & m_job_explose2<=50 & syear>=1999
replace m_job_explose_rec = 2 if m_job_explose2>=60 & m_job_explose2<=90 & syear>=1999
replace m_job_explose_rec = 1 if m_job_explose2==100 & syear>=1999
}

**COMMENT: Generate lagged of occupation variables mother and father
sort pidkid syear
foreach var of varlist m_civils m_military m_pensioner m_notemp m_regunemp m_privemp m_cureduc m_selfemp m_occ f_civils f_military f_pensioner f_notemp f_regunemp f_privemp f_cureduc f_selfemp f_occ f_jobsecworry m_jobsecworry m_job_explose1 m_job_explose2 f_job_explose1 f_job_explose2  m_job_explose_rec f_job_explose_rec {
	by pidkid  : gen `var'_lag=`var'[_n-1]
}

bro pidmother pidkid syear m_civils m_civils_lag m_military m_pensioner m_notemp m_regunemp m_privemp m_cureduc m_selfemp m_occ f_jobsecworry f_jobsecworry_lag m_jobsecworry_lag m_jobsecworry 

////////////////////////////////////////////////////////////////////////////////
****************  T R E A T M E N T      V A R I A B L E S  ********************
********** MOTHERS AND FATHERS JOB LOSS BECAUSE OF MAIN PLANT CLOSURE **********
////////////////////////////////////////////////////////////////////////////////

**********************
*** 1.1.c. FATHERS ***
**********************

***FOCAL INDEPENDENT VARIABLE - Unemployment due to plant closure for fathers  
sort pidkid syear
gen f_plantclosure = 0 if f_privemp_lag==1 & f_privemp==1 & f_age>15 & f_age<68 
**Note: Obtain the treatment by combining the information on (-) plant closure,
**															 (-) private employement in the previous period, and
**															 (-) currently registered unemployed
replace f_plantclosure = 1 if f_unempreason==1 & f_privemp_lag==1 & f_regunemp==1 & f_age>15 & f_age<68 
tab f_plantclosure, m
sort pidkid syear
bro pidkid syear f_plantclosure f_plant  f_regunemp  f_regunemp_lag f_privemp  f_privemp_lag 

**Note: No info for 1999 and 2000, replace as . (missing)
replace f_plantclosure=. if syear==1999 | syear==2000 | syear<1991
tab f_plantclosure, m


**********************************************************
*** 2.2.c. MOTHERS - WORKING AND/OR OUT OF LABOR FORCE ***
**********************************************************

***FOCAL INDEPENDENT VARIABLE - Unemployment due to plant closure for mother EITHER not employed or working in the previous time period
sort pidkid syear
gen m_plantclosure = 0 if (m_privemp_lag==1 & m_privemp==1 & m_age>15 & m_age<68) | (m_notemp_lag==1 & m_notemp==1 & m_age>15 & m_age<68) | (m_privemp_lag==1 & m_notemp==1 & m_age>15 & m_age<68) | (m_notemp_lag==1 & m_privemp==1 & m_age>15 & m_age<68)
**Note: Obtain the treatment by combining the information on (-) plant closure,
**															 (-) private employement in the previous period or out of labor force, and
**															 (-) currently registered unemployed
replace m_plantclosure = 1 if (m_unempreason==1 & m_privemp_lag==1  & m_regunemp==1 & m_age>15 & m_age<68) | (m_unempreason==1 & m_notemp_lag==1  & m_regunemp==1 & m_age>15 & m_age<68) 
tab m_plantclosure, m
sort pidkid syear
bro pidkid syear m_plantclosure m_unempreason  m_regunemp  m_regunemp_lag m_privemp  m_privemp_lag  m_notemp m_notemp_lag

**Note: No info for 1999 and 2000, replace as . (missing)
replace m_plantclosure=. if syear==1999 | syear==2000 | syear<1991
tab m_plantclosure, m


**Note: Create plant closure variables for both parents and separate versions
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////
***Parental unemployment DUE TO PLANT CLOSING at age 0
**For all variables, generate the values when the kids were 0-1 years old, etc. 
**At age 0**
sort pidkid syear
by pidkid: gen plantc0 = 0 if (m_plantclosure==0 & f_plantclosure==0 & c_age==0 & c_gebmonat<=c_pgmonth & c_gebmonat!=. & c_pgmonth!=.) | (m_plantclosure==0 & c_age==0 & c_gebmonat<=c_pgmonth & c_gebmonat!=. & c_pgmonth!=. & pidmother!=. & pidfather==.) | (f_plantclosure==0 & c_age==0 & c_gebmonat<=c_pgmonth & c_gebmonat!=. & c_pgmonth!=. & pidmother==. & pidfather!=.)
by pidkid: replace plantc0 = 1 if ((m_plantclosure==1 | f_plantclosure==1) & (m_plantclosure!=. & f_plantclosure!=.) & c_age==0 & c_gebmonat<=c_pgmonth & c_gebmonat!=. & c_pgmonth!=.) | (m_plantclosure==1 & c_age==0 & c_gebmonat<=c_pgmonth & c_gebmonat!=. & c_pgmonth!=. & pidmother!=. & pidfather==.) | (f_plantclosure==1 & c_age==0 & c_gebmonat<=c_pgmonth & c_gebmonat!=. & c_pgmonth!=. & pidmother==. & pidfather!=.)
bro pidkid syear c_age plantc0  m_plantclosure f_plantclosure
tab plantc0

**Parental unemployment DUE TO PLANT CLOSING at ages 1 or more years old (max. 15 years old)
**At age >=1**
sort pidkid syear
forval j=1/15 {
	   by pidkid: gen plantc`j' = 0 if (m_plantclosure==0 & f_plantclosure==0 & c_age==`j') | (m_plantclosure==0 & c_age==`j' & pidmother!=. & pidfather==.) | (f_plantclosure==0 & c_age==`j' & pidmother==. & pidfather!=.)
	   by pidkid: replace plantc`j' = 1 if ((m_plantclosure==1 | f_plantclosure==1) & (m_plantclosure!=. & f_plantclosure!=.) & c_age==`j') | (m_plantclosure==1 & c_age==`j' & pidmother!=. & pidfather==.) | (f_plantclosure==1 & c_age==`j' & pidmother==. & pidfather!=.)
}


**Note: For each variable now generate the maxed version  
sort pidkid syear
foreach var of varlist plantc0-plantc15 {
	by pidkid: egen max`var' = max(`var')
	drop `var'
	rename max`var' `var'
}

//**//**//**//**//**//**//**//**//**//**//**//**//**//**//**//**//**//**//**//**//**//**//**//**//**//**//**//**//
***Parental unemployment DUE TO PLANT CLOSING at age 0 - Fathers only
**For all variables, generate the values when the kids were 0-1 years old, etc. 
**At age 0**
sort pidkid syear
by pidkid: gen plantcdad0 = 0 if (f_plantclosure==0 & m_plantclosure!=. & c_age==0 & c_gebmonat<=c_pgmonth & c_gebmonat!=. & c_pgmonth!=.) | (f_plantclosure==0 & c_age==0 & c_gebmonat<=c_pgmonth & c_gebmonat!=. & c_pgmonth!=. & pidmother==. & pidfather!=.)
by pidkid: replace plantcdad0 = 1 if (f_plantclosure==1 & m_plantclosure!=. & c_age==0 & c_gebmonat<=c_pgmonth & c_gebmonat!=. & c_pgmonth!=.) | (f_plantclosure==1 & c_age==0 & c_gebmonat<=c_pgmonth & c_gebmonat!=. & c_pgmonth!=. & pidmother==. & pidfather!=.)

***Parental unemployment DUE TO PLANT CLOSING at ages 1 or more years old (max. 15 years old)
**At age >=1**
sort pidkid syear
forval j=1/15 {
	   by pidkid: gen plantcdad`j' = 0 if (f_plantclosure==0 & m_plantclosure!=. & c_age==`j') | (f_plantclosure==0 & c_age==`j' & pidmother==. & pidfather!=.)
	   by pidkid: replace plantcdad`j' = 1 if (f_plantclosure==1 & m_plantclosure!=. & c_age==`j') | (f_plantclosure==1 & c_age==`j' & pidmother==. & pidfather!=.)
}


**Note: For each variable now generate the maxed version  
sort pidkid syear
foreach var of varlist  plantcdad0-plantcdad15 {
	by pidkid: egen max`var' = max(`var')
	drop `var'
	rename max`var' `var'
}

//**//**//**//**//**//**//**//**//**//**//**//**//**//**//**//**//**//**//**//**//**//**//**//**//**//**//**//**//
***Parental unemployment DUE TO PLANT CLOSING at age 0 - Mothers only
**For all variables, generate the values when the kids were 0-1 years old, etc. 
**At age 0**
sort pidkid syear
by pidkid: gen plantcmom0 = 0 if (m_plantclosure==0 & f_plantclosure!=. & c_age==0 & c_gebmonat<=c_pgmonth & c_gebmonat!=. & c_pgmonth!=.) | (m_plantclosure==0 & c_age==0 & c_gebmonat<=c_pgmonth & c_gebmonat!=. & c_pgmonth!=. & pidmother!=. & pidfather==.) 
by pidkid: replace plantcmom0 = 1 if (m_plantclosure==1 & f_plantclosure!=. & c_age==0 & c_gebmonat<=c_pgmonth & c_gebmonat!=. & c_pgmonth!=.) | (m_plantclosure==1 & c_age==0 & c_gebmonat<=c_pgmonth & c_gebmonat!=. & c_pgmonth!=. & pidmother!=. & pidfather==.)

***Parental unemployment DUE TO PLANT CLOSING at ages 1 or more years old (max. 15 years old)
**At age >=1**
sort pidkid syear
forval j=1/15 {
	   by pidkid: gen plantcmom`j' = 0 if (m_plantclosure==0 & f_plantclosure!=. & c_age==`j') | (m_plantclosure==0 & c_age==`j' & pidmother!=. & pidfather==.)
	   by pidkid: replace plantcmom`j' = 1 if (m_plantclosure==1 & f_plantclosure!=. & c_age==`j') | (m_plantclosure==1 & c_age==`j' & pidmother!=. & pidfather==.)
}


**Note: For each variable now generate the maxed version  
sort pidkid syear
foreach var of varlist plantcmom0-plantcmom15 {
	by pidkid: egen max`var' = max(`var')
	drop `var'
	rename max`var' `var'
}	

**Note: Create a variable for the year when plant closure occurred
sort pidkid syear
forvalues i = 0(1)15 {
	bys pidkid: gen ypcl`i' = c_birthyear + `i' if plantc`i'==1
	bys pidkid: replace ypcl`i' = 0 if plantc`i'==0
}

egen ypc = rmax(ypcl0-ypcl15)
label var ypc "Year when plant closure occurred"

**Note: Now, create the unique time-period treatment indicator (and split for parental gender)
sort pidkid syear
egen plant015 = rmax(plantc0 plantc1 plantc2 plantc3 plantc4 plantc5 plantc6 plantc7 plantc8 plantc9 plantc10 plantc11 plantc12 plantc13 plantc14 plantc15)
egen plantmom015 = rmax(plantcmom0 plantcmom1 plantcmom2 plantcmom3 plantcmom4 plantcmom5 plantcmom6 plantcmom7 plantcmom8 plantcmom9 plantcmom10 plantcmom11 plantcmom12 plantcmom13 plantcmom14 plantcmom15)
egen plantdad015 = rmax(plantcdad0 plantcdad1 plantcdad2 plantcdad3 plantcdad4 plantcdad5 plantcdad6 plantcdad7 plantcdad8 plantcdad9 plantcdad10 plantcdad11 plantcdad12 plantcdad13 plantcdad14 plantcdad15)


///////////////////////////////////////////////////////////////////
/////////////** G E N E R I C   U N E M P L O Y M E N T **/////////
///////////////////////////////////////////////////////////////////

****************
**1d. FATHERS **
****************

**Note: Create binary generic unemployment variable, 1 when father is generically unemployed
**													  0 keep working
sort pidkid syear
fre f_unempreason

***FOCAL TREATMENT VARIABLE  - Generic unemployment for fathers
sort pidkid syear
gen f_unemp = 0 if f_privemp_lag==1 & f_privemp==1 & f_age>15 & f_age<68
 
**Note: Obtain the treatment by combining the information on (-) generic unemployment,
**		  												     (-) private employement in the previous period, and
**														     (-) currently registered unemployed
replace f_unemp = 1 if (f_unempreason==1 & f_privemp_lag==1 & f_regunemp==1 & f_age>15 & f_age<68) | (f_unempreason==2 & f_privemp_lag==1 & f_regunemp==1 & f_age>15 & f_age<68) | (f_unempreason==3 & f_privemp_lag==1 & f_regunemp==1 & f_age>15 & f_age<68) | (f_unempreason==4 & f_privemp_lag==1 & f_regunemp==1 & f_age>15 & f_age<68)
tab f_unemp, m
sort pidkid syear f_unemp


****************************************************
**2d. MOTHERS - WORKING AND/OR OUT OF LABOR FORCE **
****************************************************

**COMMENT: We allow the mothers to be out of the labor force OR working in the previous period [IMPORTANT]
**COMMENT: Mothers can access to maternal leaves and stay out from the employment for while and still be in the organic of the firm

**Note: Create binary generical unemployment variable, 1 when mother is generically unemployed
**													   0 keep working
sort pidkid syear
tab m_unempreason

***FOCAL TREATMENT VARIABLE - Generic unemployment for mother EITHER not employed or working in the previous time period
sort pidkid syear
gen m_unemp = 0 if (m_privemp_lag==1 & m_privemp==1 & m_age>15 & m_age<68) | (m_notemp_lag==1 & m_notemp==1 & m_age>15 & m_age<68) | (m_privemp_lag==1 & m_notemp==1 & m_age>15 & m_age<68) | (m_notemp_lag==1 & m_privemp==1 & m_age>15 & m_age<68)

**Note: Obtain the treatment by combining the information on (-) generic unemployment,
**															 (-) private employement in the previous period, and
**															 (-) currently registered unemployed
replace m_unemp = 1 if (m_unempreason==1 & m_privemp_lag==1 & m_regunemp==1 & m_age>15 & m_age<68) | (m_unempreason==1 & m_notemp_lag==1 & m_regunemp==1 & m_age>15 & m_age<68) | (m_unempreason==2 & m_privemp_lag==1 & m_regunemp==1 & m_age>15 & m_age<68) | (m_unempreason==2 & m_notemp_lag==1 & m_regunemp==1 & m_age>15 & m_age<68) | (m_unempreason==3 & m_privemp_lag==1 & m_regunemp==1 & m_age>15 & m_age<68) | (m_unempreason==3 & m_notemp_lag==1 & m_regunemp==1 & m_age>15 & m_age<68) | (m_unempreason==4 & m_privemp_lag==1 & m_regunemp==1 & m_age>15 & m_age<68) | (m_unempreason==4 & m_notemp_lag==1 & m_regunemp==1 & m_age>15 & m_age<68) 
tab m_unemp, m
sort pidkid syear


/////////////////////////////////////////////////////////////////////////////////////////////////////////////////
***Parental GENERIC unemployment at age 0
**Note: For all variables, generate the values when the kids were 0-1 years old, etc. 
**At age 0**
sort pidkid syear
by pidkid: gen unemp0 = 0 if (m_unemp==0 & f_unemp==0 & c_age==0 & c_gebmonat<=c_pgmonth & c_gebmonat!=. & c_pgmonth!=.) | (m_unemp==0 & c_age==0 & c_gebmonat<=c_pgmonth & c_gebmonat!=. & c_pgmonth!=. & pidmother!=. & pidfather==.) | (f_unemp==0 & c_age==0 & c_gebmonat<=c_pgmonth & c_gebmonat!=. & c_pgmonth!=. & pidmother==. & pidfather!=.)
by pidkid: replace unemp0 = 1 if ((m_unemp==1 | f_unemp==1) & (m_unemp!=. | f_unemp!=.) & c_age==0 & c_gebmonat<=c_pgmonth & c_gebmonat!=. & c_pgmonth!=.) | (m_unemp==1 & c_age==0 & c_gebmonat<=c_pgmonth & c_gebmonat!=. & c_pgmonth!=. & pidmother!=. & pidfather==.) | (f_unemp==1 & c_age==0 & c_gebmonat<=c_pgmonth & c_gebmonat!=. & c_pgmonth!=. & pidmother==. & pidfather!=.)

***Parental GENERIC unemployment at ages 1 or more years old (max. 15 years old)
**At age >=1**
sort pidkid syear
forval j=1/15 {
	   by pidkid: gen unemp`j' = 0 if (m_unemp==0 & f_unemp==0 & c_age==`j') | (m_unemp==0 & c_age==`j' & pidmother!=. & pidfather==.) | (f_unemp==0 & c_age==`j' & pidmother==. & pidmother!=.) 
	   by pidkid: replace unemp`j' = 1 if ((m_unemp==1 | f_unemp==1) & (m_unemp!=. | f_unemp!=.) & c_age==`j') | (m_unemp==1 & c_age==`j' & pidmother!=. & pidfather==.) | (f_unemp==1 & c_age==`j' & pidmother==. & pidfather!=.)
}


**Note: Foreach variable now generate the maxed version  
sort pidkid syear
foreach var of varlist unemp0-unemp15 {
	by pidkid: egen max`var' = max(`var')
	drop `var'
	rename max`var' `var'
}

**Note: Now, create the unique time-period generic treatment indicator
sort pidkid syear
egen unemp015 = rmax(unemp0 unemp1 unemp2 unemp3 unemp4 unemp5 unemp6 unemp7 unemp8 unemp9 unemp10 unemp11 unemp12 unemp13 unemp14 unemp15)

**Note: Create a variable to flag possible bad controls, that is individuals with
**		parents that did suffered parental unemployment but not due to a plant
**		closure.
gen exc015 = 1 if plant015==0 & unemp015==1


**********************************************************************
***Unemployment experience (FATHER-MOTHER)
**********************************************************************

sort pidkid syear 
*bro pidkid pidmother pidfather f_pgexpue m_pgexpue

***Work experience and unemployment experience with a missing indicator
label define exp 1 "Missing" 2"0" 3 "5 and less" 4 "More than 5"
fre m_pgexpue f_pgexpue
foreach var of varlist m_pgexpue f_pgexpue  {
	gen `var'1 = 1 if `var'==.
	replace `var'1 = 2 if `var'==0
	replace `var'1 = 3 if `var'>0 & `var'<=5
	replace `var'1 = 4 if `var'>5 & `var'!=.
	label values `var'1 exp
}


***Job security with missing information
**Note: It is the current one for the kid and the past one for the parents
sort pidkid syear
foreach var of varlist m_jobsecworry_lag f_jobsecworry_lag {
	fre	 `var'
	gen `var'1 = 1 if `var'==.
	replace `var'1 = 2 if `var'==1
	replace `var'1 = 3 if `var'==2
	replace `var'1 = 4 if `var'==3
	label var `var'1 "`var', 1=Missing, 2=Big worries, 2=Some worries, 3=Mo worries"
	tab `var' `var'1, m
}
	

	
//////////////////////////////////////////////////////////////////////
**********************************************************************
/////////////////** SOCIO-ECONOMIC CHARACTERISTICS **/////////////////
**********************************************************************
//////////////////////////////////////////////////////////////////////


**********************************************************************
******%%%%%%%%%%%%%%%%%%%%%% INDIVIDUAL %%%%%%%%%%%%%%%%%%%%%%%%******
**********************************************************************
**********************************************************************
******AGE, BIRTHYEAR AND AGE When CHILD WAS BORN (CHILD-FATHER-MOTHER)
**********************************************************************

format c_birthyear m_birthyear f_birthyear %ty

********
**KIDS**
********

***Kids' BIRTHYEAR
**COMMENT: Now fill in the kid's BIRTHYEAR if it is missing
sort pidkid syear
by pidkid: egen max = max(c_birthyear)
by pidkid: replace c_birthyear = max if c_birthyear==.
drop max
bro pidkid syear c_birthyear 

***Kids' AGE
**COMMENT: Now fill in kid's AGE if it is missing
sort pidkid syear
by pidkid: replace c_age = syear - c_birthyear if c_age==.


***********
**FATHERS**
***********

***Father's BIRTHYEAR
**COMMENT: Try to fix what could be fixed (ie. fill in it)
by pidkid: egen max = max(f_birthyear)
by pidkid: replace f_birthyear = max if f_birthyear==.
drop max

***Father's AGE when the kid was born
**COMMENT: Look at how old the father was when the kid was born 
**COMMENT: For each child there might be more than one child can have the same father 
sort pidkid syear
bro pidkid syear c_birthyear pidfather f_birthyear f_age
by pidkid: gen long f_agekidborn = c_birthyear - f_birthyear


**COMMENT: Fill in the information (populate it if it is missing) for how old the
**		   father was when the kid was born [IMPORTANT]. This information doesn't
**		   change per child
sort pidkid syear
by pidkid: egen maxf_agekidborn = max(f_agekidborn)
by pidkid: replace f_agekidborn = maxf_agekidborn if f_agekidborn==. & maxf_agekidborn!=.
drop maxf_agekidborn

**COMMENT: There are NO kids whereby the fathers were 10 years old or less when 
**		   they had kids, but in case replace them with missing
replace  f_agekidborn=. if f_agekidborn<=10

***********
**MOTHERS**
***********

***Mother's  BIRTHYEAR
**COMMENT: Populate the variable if it is missing (ie. fill in it)
sort pidkid syear
by pidkid: egen max = max(m_birthyear)
by pidkid: replace m_birthyear = max if m_birthyear==. & max!=.
drop max


***Mother's AGE when the kid was born
**COMMENT: Look at how old the mother was when the kid was born 
**COMMENT: For each child there might be more than one child can have the same mother 
sort pidkid syear
bro pidkid syear c_birthyear pidmother m_birthyear m_age
by pidkid: gen m_agekidborn = c_birthyear - m_birthyear

**COMMENT: Fill in the information (populate it if it is missing) for how old the
**		   mother was when the kid was born [IMPORNTANT]. This information doesn't
**		   change per child
sort pidkid syear
by pidkid: egen maxm_agekidborn = max(m_agekidborn)
by pidkid: replace m_agekidborn = maxm_agekidborn if m_agekidborn==. & maxm_agekidborn!=.
drop maxm_agekidborn

**COMMENT: There are NO kids whereby the mothers were 10 years old or less when 
**		   they had kids, but in case replace them with missing
replace  m_agekidborn=. if m_agekidborn<=10


**Note: Generate indicators for mother and father ages when born 
foreach var of varlist m_agekidborn f_agekidborn {
	gen `var'1 = 1 if `var'==.
	replace `var'1 = 2 if `var'>=10 & `var'<=20
	replace `var'1 = 3 if `var'>=21 & `var'<=25
	replace `var'1 = 4 if `var'>=26 & `var'<=30
	replace `var'1 = 5 if `var'>=31 & `var'<=35
	replace `var'1 = 6 if `var'>=36 & `var'<=40
	replace `var'1 = 7 if `var'>40 & `var'!=.
	label var `var'1 "``var'' 1=Missing, 2=20 and under, 3=21-25, 4=26-30, 5=31-35, 6=36-40, 7=41 and older"
}	

**Note: Now create the dummies
*Fathers
tab f_agekidborn1, gen(df_agekidborn1)
rename df_agekidborn11 df_akbm
label var df_akbm "Father's age at which kid is born: missing"
rename df_agekidborn12 df_akb20l
label var df_akb20l "Father's age at which kid is born: 20 and under"
rename df_agekidborn13 df_akb2125
label var df_akb2125 "Father's age at which kid is born: 21-25"
rename df_agekidborn14 df_akb2630
label var df_akb2630 "Father's age at which kid is born: 26-30"
rename df_agekidborn15 df_akb3135
label var df_akb3135 "Father's age at which kid is born: 31-35"
rename df_agekidborn16 df_akb3640
label var df_akb3640 "Father's age at which kid is born: 36-40"
rename df_agekidborn17 df_akb41m
label var df_akb41m "Father's age at which kid is born: 41 and more"

*Mothers
tab m_agekidborn1, gen(dm_agekidborn1)
rename dm_agekidborn11 dm_akbm
label var dm_akbm "Mother's age at which kid is born: missing"
rename dm_agekidborn12 dm_akb20l
label var dm_akb20l "Mother's age at which kid is born: 20 and under"
rename dm_agekidborn13 dm_akb2125
label var dm_akb2125 "Mother's age at which kid is born: 21-25"
rename dm_agekidborn14 dm_akb2630
label var dm_akb2630 "Mother's age at which kid is born: 26-30"
rename dm_agekidborn15 dm_akb3135
label var dm_akb3135 "Mother's age at which kid is born: 31-35"
rename dm_agekidborn16 dm_akb3640
label var dm_akb3640 "Mother's age at which kid is born: 36-40"
rename dm_agekidborn17 dm_akb41m
label var dm_akb41m "Mother's age at which kid is born: 41 and more"

**********************************************************************
******HOUSEHOLD INCOME (CHILD)
**********************************************************************

***Household income (CHILD PERSPECTIVE)
**COMMENT: For each year compute the average of the mother's and father's income
sort pidkid syear
egen c_dispinc_real_1 = rowmean(f_dispinc_real m_dispinc_real)
*bro pidkid syear c_dispinc_real c_dispinc_real_1 f_dispinc_real m_dispinc_real

***Income quintiles
**COMMENT: Use quintiles so that also missing information can be assigned
**Foreach year
sort syear
xtile c_incq = c_dispinc_real_1, n(5)
label var  c_incq "Income quintile"
***Generate an income quintile variable with missing info
sort pidkid syear
gen c_incq1 = 1 if c_incq==.
replace c_incq1 = 2 if c_incq==1
replace c_incq1 = 3 if c_incq==2
replace c_incq1 = 4 if c_incq==3
replace c_incq1 = 5 if c_incq==4
replace c_incq1 = 6 if c_incq==5
label var c_incq1 "Income quintile, 1=Missing, 2=1st quintile, 3=2nd quintile, 4=3rd quintile, 5=4th quintile, 6=5th quintile"
tab c_incq c_incq1, m


**********************************************************************
******EDUCATION (FATHER-MOTHER)
**********************************************************************

***COMMENT: Education variable with missing information indicator
sort pidkid syear
by pidkid: egen dadeduc = max(f_educdum)
by pidkid: egen momeduc = max(m_educdum)

**Missing indicator in maximum parental education 
foreach var of varlist dadeduc momeduc {
	gen `var'1 = 1 if `var'==.
	replace `var'1 = 2 if `var'==1
	replace `var'1 = 3 if `var'==2
	replace `var'1 = 4 if `var'==3
	label values `var'1 educ1
}

fre dadeduc1 momeduc1
*Fathers
tab dadeduc1, gen(df_dadeduc1)
rename df_dadeduc11 df_edum
label var df_edum "Father educational level achieved: missing"
rename df_dadeduc12 df_edulh
label var df_edulh "Father educational level achieved: less than HS"
rename df_dadeduc13 df_eduhs
label var df_eduhs "Father educational level achieved: HS"
rename df_dadeduc14 df_eduter
label var df_eduter "Father educational level achieved: tertiary education"

*Mothers
tab momeduc1, gen(dm_momeduc1)
rename dm_momeduc11 dm_edum
label var dm_edum "Mother educational level achieved: missing"
rename dm_momeduc12 dm_edulh
label var dm_edulh "Mother educational level achieved: less than HS"
rename dm_momeduc13 dm_eduhs
label var dm_eduhs "Mother educational level achieved: HS"
rename dm_momeduc14 dm_eduter
label var dm_eduter "Mother educational level achieved: tertiary education"

**********************************************************************
******GENERAL INFORMATION 
**********************************************************************

***Migration background
**Note: Cleaning up
foreach var of varlist c_migback f_migback m_migback {
	replace `var'=. if `var'<0
	recode `var' 1=0 2 3 4=1
}

**COMMENT: For each kid, fill in the information about own, mother's and father's background 
**         Once the father has a migration background, he always has it, etc. 
sort pidkid syear
foreach var of varlist c_migback f_migback m_migback {
	by pidkid: egen max`var' = max(`var')
	by pidkid: replace `var' = max`var' if `var'==. & max`var'!=.
	drop max`var'
}

rename c_migback c_migra
label var c_migra "Dummy for child migrational background, 0=no, 1=yes"
rename f_migback f_migra
label var f_migra "Dummy for paternal migrational background, 0=no, 1=yes"
rename m_migback m_migra
label var m_migra "Dummy for maternal migrational background, 0=no, 1=yes"
fre *_migra

***Number of siblings 
bro pidkid syear c_nokid m_nokid f_nokid f_h11101 f_h11102 m_h11101 m_h11102 f_ownchild m_ownchild
sort pidkid syear
egen kids = rowmax(c_nokid m_nokid f_nokid f_h11101 f_h11102 m_h11101 m_h11102 f_ownchild m_ownchild)
bro pidkid syear kids c_nokid m_nokid f_nokid f_h11101 f_h11102 m_h11101 m_h11102 f_ownchild m_ownchild
by pidkid syear: replace kids = 0 if kids==. & c_age==0
by pidkid syear: gen siblings = kids - 1 if kids!=. & kids>0
by pidkid syear: replace siblings = 0 if (kids==0 & c_age==0) | (kids==. & c_age==0)

***Add to ``Number of siblings'' the missing information indicator
gen c_num_sib1 = 1 if siblings==.
replace c_num_sib1 = 2 if siblings==0
replace c_num_sib1 = 3 if siblings==1
replace c_num_sib1 = 4 if siblings==2 
replace c_num_sib1 = 5 if siblings>=3 & siblings!=.
tab siblings c_num_sib1, m
label var c_num_sib1 "Number of siblings, 1=Missing, 2=No siblings (0), 3=One sibling (1), 4=Two siblings (2), 5=Three or more siblings (>=3)"

***Firstborn child in the HH
bro pidkid syear c_age c_birthyear kids siblings c_pos_sib if c_age==0
fre c_pos_sib
recode c_pos_sib -2=.

**Note: For those who are solo children they also should be coded as 1
bro pidkid syear c_num_sib c_pos_sib f_ownchild m_ownchild c_nokid c_num_sib if c_num_sib==0  
by pidkid: gen firstborn = 0 if c_pos_sib!=. & c_pos_sib!=1
by pidkid: replace firstborn = 1 if c_pos_sib!=. & c_pos_sib==1
by pidkid: egen firstbornmax = max(firstborn)
by pidkid: replace firstborn = firstbornmax if firstborn==.
rename firstborn fb
label var fb "Is the person the first born child? 0=no, 1=yes"
drop firstbornmax

**Note: Create the missing information indicator to ``Firstborn''
sort pidkid syear
gen misfb = 0
replace misfb = 1 if fb==.
replace fb = 0 if misfb==1
label var misfb "Is the person the first born child? Missing information"

***COMMENT: Create the home size variable with a missing indicator
fre c_hgsize 
gen c_hgsize1 = 1 if c_hgsize==.
replace c_hgsize1 = 2 if c_hgsize<=50 & c_hgsize!=.
replace c_hgsize1 = 3 if c_hgsize>=51 & c_hgsize<=100
replace c_hgsize1 = 4 if c_hgsize>=101 & c_hgsize<=150
replace c_hgsize1 = 5 if c_hgsize>=151 & c_hgsize!=.
label define c_hgsize 1 "Missing " 2 "50 and less" 3 "51-100" 4 "101-150" 5 "151 and larger"
label values c_hgsize1 hgsize
tab c_hgsize c_hgsize1, m


***COMMENT: Create the state indicator where a person is born or grew up in
**Note: For many kids in the first year the state is missing, assign it to the 
**		same as the mother (or the father if single-parent household with male head).
**VAR: Geographical areas, composed by Landers, in which person is born or the first available (NEW)
**Note: For treated individuals, we use birth state before the treatment
*Age 0
clonevar c_birsta0 = c_state if c_state!=. & c_age==0 & c_gebmonat<=c_pgmonth & c_gebmonat!=. & c_pgmonth!=.
bys pidkid: replace c_birsta0 = m_state if m_state!=. & c_age==0 & pidmother!=. & pidfather!=. & c_gebmonat<=c_pgmonth & c_gebmonat!=. & c_pgmonth!=.
bys pidkid: replace c_birsta0 = f_state if m_state==. & f_state!=. & c_age==0 & pidmother!=. & pidfather!=. & c_gebmonat<=c_pgmonth & c_gebmonat!=. & c_pgmonth!=.
bys pidkid: replace c_birsta0 = m_state if m_state!=. & c_age==0 & pidmother!=. & pidfather==. & c_gebmonat<=c_pgmonth & c_gebmonat!=. & c_pgmonth!=.
bys pidkid: replace c_birsta0 = f_state if f_state!=. & c_age==0 & pidmother==. & pidfather!=. & c_gebmonat<=c_pgmonth & c_gebmonat!=. & c_pgmonth!=.
*bys pidkid: replace c_birsta = c_birsta[_n-1] if c_birsta[_n-1]!=. & c_birsta==.

*Age 1, 2, 3, 4, 5, ..., ect.
forvalues i = 1(1)15 {
	clonevar c_birsta`i' = c_state if c_state!=. & c_age==`i'
	bys pidkid: replace c_birsta`i' = m_state if m_state!=. & c_age==`i' & pidmother!=. & pidfather!=.
	bys pidkid: replace c_birsta`i' = f_state if m_state==. & f_state!=. & c_age==`i' & pidmother!=. & pidfather!=.
	bys pidkid: replace c_birsta`i' = m_state if m_state!=. & c_age==`i' & pidmother!=. & pidfather==.
	bys pidkid: replace c_birsta`i' = f_state if f_state!=. & c_age==`i' & pidmother==. & pidfather!=.
}

*Temp
clonevar c_birstatemp = c_state
replace c_birstatemp = .
bys pidkid: replace c_birstatemp = c_birsta0
bys pidkid: replace c_birstatemp = c_birstatemp[_n-1] if c_birstatemp[_n-1]!=. & c_birstatemp==.
forvalues i = 1(1)15 {
	bys pidkid: replace c_birstatemp = c_birsta`i' if c_birstatemp==.
	bys pidkid: replace c_birstatemp = c_birstatemp[_n-1] if c_birstatemp[_n-1]!=. & c_birstatemp==.
}
*Actual
bys pidkid: egen c_birsta = max(c_birstatemp)
label define c_birsta 1 "Schleswig-Holstein" 2 "Hamburg" 3 "Niedersachsen" 4 "Bremen" 5 "Nordrhein-Westfalen" 6 "Hessen" 7 "Rheinland-Pfalz" 8 "Baden-Wuerttemberg" 9 "Bayern" 10 "Saarland" 11 "Berlin" 12 "Brandenburg" 13 "Mecklenburg-Vorpommern" 14 "Sachsen" 15 "Sachsen-Anhalt" 16 "Thueringen"
label value c_birsta c_birsta

**Note: Create the geographical areas, composed by Landers, in which person is born
tab c_birsta, gen(d_state)
cap drop d_state17
rename d_state1 state1
label var state1 "Region of birth: Schleswig-Holstein"
rename d_state2 state2
label var state2 "Region of birth: Hamburg"
rename d_state3 state3
label var state3 "Region of birth: Niedersachsen"
rename d_state4 state4
label var state4 "Region of birth: Bremen"
rename d_state5 state5
label var state5 "Region of birth: Nordrhein-Westfalen"
rename d_state6 state6
label var state6 "Region of birth: Hessen"
rename d_state7 state7
label var state7 "Region of birth: Rheinland-Pfalz"
rename d_state8 state8
label var state8 "Region of birth: Baden-Wuerttemberg"
rename d_state9 state9
label var state9 "Region of birth: Bayern"
rename d_state10 state10
label var state10 "Region of birth: Saarland"
rename d_state11 state11
label var state11 "Region of birth: Berlin"
rename d_state12 state12
label var state12 "Region of birth: Brandenburg"
rename d_state13 state13
label var state13 "Region of birth: Mecklenburg-Vorpommern"
rename d_state14 state14
label var state14 "Region of birth: Sachsen"
rename d_state15 state15
label var state15 "Region of birth: Sachsen-Anhalt"
rename d_state16 state16
label var state16 "Region of birth: Thueringen"
bys pidkid: gen bweger = 0
bys pidkid: replace bweger = 1 if state1==1 | state2==1 | state3==1 | state4==1 | state5==1 | state6==1 | state7==1 | state8==1 | state9==1 | state10==1 | state11==1
label var bweger "Before German re-unification reference zone: West"
bys pidkid: gen beager = 0
bys pidkid: replace beager = 1 if state12==1 | state13==1 | state14==1 | state15==1 | state16==1
label var beager "Before German re-unification reference zone: East"


**Note: Create another indicator to link unemployment rates later on
by pidkid: replace c_state1 = m_state if (c_state1==17 | c_state==. | c_state1==.) & c_age==0
replace c_state1 = 17 if c_state1==.
tab c_state c_state1, m


**Save a temp file
save temp.dta, replace

**Note: Now merge in with the information about the unemployment rate when they were kids

clear
use "unemp_by_state.dta", clear
xtset state year
rename state geog
gen state = word("Deutschland SchleswigHolstein Hamburg Niedersachsen Bremen NordrheinWestfalen Hessen RheinlandPfalz BadenWuerttemberg Bayern Saarland Berlin Brandenburg MecklenburgVorpommern Sachsen SachsenAnhalt Thueringen", geog)
rename year c_birthyear
tab state
gen c_state=8 if state=="BadenWuerttemberg"
replace c_state=1 if state=="SchleswigHolstein"
replace c_state=2 if state=="Hamburg"
replace c_state=3 if state=="Niedersachsen"
replace c_state=4 if state=="Bremen"
replace c_state=5 if state=="NordrheinWestfalen"
replace c_state=6 if state=="Hessen"
replace c_state=7 if state=="RheinlandPfalz"

replace c_state=9 if state=="Bayern"
replace c_state=10 if state=="Saarland"
replace c_state=11 if state=="Berlin"
replace c_state=12 if state=="Brandenburg"
replace c_state=13 if state=="MecklenburgVorpommern"
replace c_state=14 if state=="Sachsen"
replace c_state=15 if state=="SachsenAnhalt"
replace c_state=16 if state=="Thueringen"
replace c_state=17 if state=="Deutschland"

rename c_state c_state1
rename s stateunemp

**Note: Create the national unemployment clone
sort c_birthyear
gen nat = stateunemp if c_state1==17
by c_birthyear: egen maxnat = max(nat)
drop nat
rename maxnat natunemp

**COMMENT: This is for east germany before 1991
sort c_state1 c_birthyear
bys c_state1: replace stateunemp = natunemp  if stateunemp==. 

**Note: Restrict the sample for those kids born from the 1984 onwards
keep if c_birthyear>=1984
drop natunemp


**Note: Compute the unemployment rate at each year

**COMMENT: the 1985 has to be computed outside the loop
**For 1985 it has to be outside the loop
sort c_state1 c_birthyear
forval i=1984/2019 {
	   by c_state1: gen c_stateunemp_`i' = stateunemp if c_birthyear==`i'
	   }

foreach var of varlist c_stateunemp_1984-c_stateunemp_2019 {
		by c_state1: egen max`var' = max(`var')
		drop `var'
		rename max`var' `var'
		}
		

**Note: Restrict the sample for those kids born from the 1984 onwards
keep if c_birthyear>=1984

**Note: Keep only one observation per state [IMPORTANT]
by c_state1: keep if _n==1
drop c_birthyear

**Save the dataset
save unemp_by_state_tomerge.dta, replace


**COMMENT: Now we go back to the previous dataset and start the final part

**Merge with the temp file
use temp, clear
cap drop _merge
sort c_state1 c_birthyear 
merge m:1 c_state1 using unemp_by_state_tomerge.dta
sort pidkid syear 
*bro pidkid syear c_age c_state1 c_birthyear  stateunemp c_stateunemp* state

**Note: If the child is not yet born, replace state unemployment as missing 
foreach var of varlist c_stateunemp_1984-c_stateunemp_2019 {
		by pidkid syear: replace `var'=. if c_age<0
		}
drop _merge
drop stateunemp

**********************************************************************************************************

***COMMENT: Create unemployment rate variable when the kid is 0 years old
sort pidkid syear

**1984**
**COMMENT: You should make sure that the month of interview is AFTER the kid was born [IMPORTANT] 
by pidkid syear: gen c_unempatage0 = c_stateunemp_1984 if c_age==0 & c_gebmonat<=c_pgmonth & c_gebmonat!=. & c_pgmonth!=. & syear==1984
 
**1985 to 2019**
forval i= 1985/2019 {
	   by pidkid syear: replace c_unempatage0 = c_stateunemp_`i' if c_age==0 & c_gebmonat<=c_pgmonth & c_gebmonat!=. & c_pgmonth!=. & syear==`i' 
	   }
 
***COMMENT: Create unemployment rate when the kid is 1 or more years old (max. 15 years old)
sort pidkid syear
forval j=1/15 {
	   by pidkid: gen c_unempatage`j' = c_stateunemp_1985 if c_age==`j' & syear==1984
				  forval k=1985/2019 {
						 by pidkid syear: replace c_unempatage`j' = c_stateunemp_`k' if c_age==`j' & syear==`k'				
						 }	
	   }

  
**Note: For each variable now generate a maxed version  
**Note: The purpose now is to assign the unemployment rate for each kid at each age
sort pidkid syear
foreach var of varlist c_unempatage0-c_unempatage15 {
		by pidkid: egen max`var' = max(`var')
		drop `var'
		rename max`var' `var'
}	

**Note: Take the period averages
sort pidkid syear
egen unempatage015 = rmean(c_unempatage0-c_unempatage15)

///////////////////////
**OTHER KEY VARIABLES FOR THE ANALYSIS
///////////////////////
**COMMENT: Generate variables at ages 0, 1, 2, 3, 4, 5, etc
sort pidkid syear
foreach var of varlist c_dispinc_real_1 c_incq1 siblings c_hgsize c_state m_pgexpue f_pgexpue m_job_explose_rec_lag f_job_explose_rec_lag {
	by pidkid: gen `var'_0=`var' if c_age==0
			forval j=1/15 {
				by pidkid: gen `var'_`j'=`var' if c_age==`j'
				label var `var'_`j' "`var' at age `j'"
				by pidkid: egen max`var'_`j'=max(`var'_`j')
				drop `var'_`j'
				rename max`var'_`j' `var'_`j'
			}
}

**COMMENT: Fix the cumulative parental unemployment variables at time 0, making
**		   them time constant
*Fathers
fre f_pgexpue_0
clonevar f_cumunem0 = f_pgexpue_0
bys pidkid: replace f_cumunem0 = f_cumunem0[_n-1] if f_cumunem0[_n-1]!=. & f_cumunem0[_n]==.
bys pidkid: gen mis_f_cumunem0 = 1 if f_cumunem0[_n]==.
bys pidkid: replace mis_f_cumunem0 = 0 if f_cumunem0[_n]!=.
bys pidkid: replace f_cumunem0 = 0 if mis_f_cumunem0==1
label var f_cumunem0 "Cumulative paternal unemployment at individual's birth"

*Mothers
fre m_pgexpue_0
clonevar m_cumunem0 = m_pgexpue_0
bys pidkid: replace m_cumunem0 = m_cumunem0[_n-1] if m_cumunem0[_n-1]!=. & m_cumunem0[_n]==.
bys pidkid: gen mis_m_cumunem0 = 1 if m_cumunem0[_n]==.
bys pidkid: replace mis_m_cumunem0 = 0 if m_cumunem0[_n]!=.
bys pidkid: replace m_cumunem0 = 0 if mis_m_cumunem0==1
label var m_cumunem0 "Cumulative maternal unemployment at individual's birth"
**Note: Create also the time-period averages, with missing indicator
*Fathers
egen f_cumula_unemp = rmean(f_pgexpue_0 - f_pgexpue_15)
gen mis_f_cumula_unemp = 1 if f_cumula_unemp==.
replace mis_f_cumula_unemp = 0 if f_cumula_unemp!=.
replace f_cumula_unemp = 0 if mis_f_cumula_unemp==1

*Mothers
egen m_cumula_unemp = rmean(m_pgexpue_0 - m_pgexpue_15)
gen mis_m_cumula_unemp = 1 if m_cumula_unemp==.
replace mis_m_cumula_unemp = 0 if m_cumula_unemp!=.
replace m_cumula_unemp = 0 if mis_m_cumula_unemp==1


**COMMENT: Now the lagged parental job loss expectation indicators
**Note: Recode maternal and paternal job loss expectations
foreach var of varlist m_job_explose_rec_lag_0 m_job_explose_rec_lag_0 m_job_explose_rec_lag_1 m_job_explose_rec_lag_2 m_job_explose_rec_lag_3 m_job_explose_rec_lag_4 m_job_explose_rec_lag_5 m_job_explose_rec_lag_6 m_job_explose_rec_lag_7 m_job_explose_rec_lag_8 m_job_explose_rec_lag_9 m_job_explose_rec_lag_10 m_job_explose_rec_lag_11 m_job_explose_rec_lag_12 m_job_explose_rec_lag_13 m_job_explose_rec_lag_14 m_job_explose_rec_lag_15 f_job_explose_rec_lag_0 f_job_explose_rec_lag_1 f_job_explose_rec_lag_2 f_job_explose_rec_lag_3 f_job_explose_rec_lag_4 f_job_explose_rec_lag_5 f_job_explose_rec_lag_6 f_job_explose_rec_lag_7 f_job_explose_rec_lag_8 f_job_explose_rec_lag_9 f_job_explose_rec_lag_10 f_job_explose_rec_lag_11 f_job_explose_rec_lag_12 f_job_explose_rec_lag_13 f_job_explose_rec_lag_14 f_job_explose_rec_lag_15 {
		recode `var' 5=.
}

*Fathers
fre f_job_explose_rec_lag_0
clonevar f_jobexplo0 = f_job_explose_rec_lag_0
bys pidkid: replace f_jobexplo0 = f_jobexplo0[_n-1] if f_jobexplo0[_n-1]!=. & f_jobexplo0[_n]==.
bys pidkid: gen mis_f_jobexplo0 = 1 if f_jobexplo0[_n]==.
bys pidkid: replace mis_f_jobexplo0 = 0 if f_jobexplo0[_n]!=.
bys pidkid: replace f_jobexplo0 = 0 if mis_f_jobexplo0==1
label var f_jobexplo0 "Paternal job loss expectation at individual's birth"

*Mothers
fre m_job_explose_rec_lag_0
clonevar m_jobexplo0 = m_job_explose_rec_lag_0
bys pidkid: replace m_jobexplo0 = m_jobexplo0[_n-1] if m_jobexplo0[_n-1]!=. & m_jobexplo0[_n]==.
bys pidkid: gen mis_m_jobexplo0 = 1 if m_jobexplo0[_n]==.
bys pidkid: replace mis_m_jobexplo0 = 0 if m_jobexplo0[_n]!=.
bys pidkid: replace m_jobexplo0 = 0 if mis_m_jobexplo0==1
label var m_jobexplo0 "Maternal job loss expectation at individual's birth"
**Note: Create also the time-period averages, with missing indicator
** Fathers
egen f_expecta = rmean(f_job_explose_rec_lag_0 - f_job_explose_rec_lag_15)
gen mis_f_expecta = 1 if f_expecta==.
replace mis_f_expecta = 0 if f_expecta!=.
replace f_expecta = 0 if mis_f_expecta==1

** Mothers
egen m_expecta = rmean(m_job_explose_rec_lag_0 - m_job_explose_rec_lag_15)
gen mis_m_expecta = 1 if m_expecta==.
replace mis_m_expecta = 0 if m_expecta!=.
replace m_expecta = 0 if mis_m_expecta==1


**COMMENT: Now the siblings indicator
fre siblings_0
clonevar sib0 = siblings_0
bys pidkid: replace sib0 = sib0[_n-1] if sib0[_n-1]!=. & sib0[_n]==.
label var sib0 "Number of siblings at individual's birth"
**Note: Create also the time-period averages, with missing indicator
egen sibli = rmean(siblings_0 - siblings_15)
gen mis_sibli = 1 if sibli==.
replace mis_sibli = 0 if sibli!=.
replace sibli = 0 if mis_sibli==1


**COMMENT: Now the income quintile indicators
clonevar incq0 = c_incq1
by pidkid: replace incq0 = . if c_birthyear!=syear
bys pidkid: replace incq0 = incq0[_n-1] if incq0[_n-1]!=. & incq0[_n]==.
tab incq0, gen(incqui0)
label var incqui01 "Income quintile at age 1: Missing"
label var incqui02 "Income quintile at age 1: 1st quintile"
label var incqui03 "Income quintile at age 1: 2nd quintile"
label var incqui04 "Income quintile at age 1: 3rd quintile"
label var incqui05 "Income quintile at age 1: 4th quintile"
label var incqui06 "Income quintile at age 1: 5th quintile"
**Note: Create also the time-period averages, with missing indicator
*** Average income
sort pidkid syear
egen inc015 = rmean(c_dispinc_real_1_0-c_dispinc_real_1_15)

*** Average income quintile
sort syear
xtile inc015q = inc015, n(5)
label var inc015q "Income quintile"
gen mis_inc015q = 1 if inc015q==.
replace mis_inc015q = 0 if inc015q!=.
forvalues i = 1(1)5 {
	gen inc015q_`i' = 1 if inc015q==`i'
	replace inc015q_`i' = 0 if inc015q!=`i'
}


**COMMENT: Now the home size indicator
sort pidkid syear
clonevar hmsz0 = c_hgsize
bys pidkid: replace hmsz0 = . if c_birthyear!=syear
bys pidkid: replace hmsz0 = hmsz0[_n-1] if hmsz0[_n-1]!=. & hmsz0[_n]==.
bys pidkid: gen mis_hmsz0 = 1 if hmsz0[_n]==. & c_age==0
bys pidkid: replace mis_hmsz0 = 0 if hmsz0[_n]!=.
bys pidkid: replace mis_hmsz0 = mis_hmsz0[_n-1] if mis_hmsz0==.
bys pidkid: replace hmsz0 = 0 if mis_hmsz0==1
label var hmsz0 "Home size at individual's birth"
**Note: Create also the time-period averages, with missing indicator
egen homesize = rmean(c_hgsize_0 - c_hgsize_15)
gen mis_homesize = 1 if homesize==.
replace mis_homesize = 0 if homesize!=.
replace homesize = 0 if mis_homesize==1


**COMMENT: Create an household size indicator similar to those just did
sort pidkid syear
tab sib0 if pidmother!=. & pidfather!=.
tab sib0 if pidmother==. & pidfather!=.
tab sib0 if pidmother!=. & pidfather==.
bys pidkid: gen hhsz0 = sib0 + 2 if (pidkid!=. & pidmother!=. & pidfather==.) | (pidkid!=. & pidmother==. & pidfather!=.)
bys pidkid: replace hhsz0 = sib0 + 3 if pidkid!=. & pidmother!=. & pidfather!=.
label var hhsz0 "Household size at individual's birth"
**Note: Create also the time-period averages, with missing indicator
clonevar householdsize_0 = hhsz0
forvalues i = 1(1)15 {
clonevar sib`i' = siblings_`i'
bys pidkid: replace sib`i' = sib`i'[_n-1] if sib`i'[_n-1]!=. & sib`i'[_n]==.
bys pidkid: gen mis_sib`i' = 1 if sib`i'[_n]==.
bys pidkid: replace mis_sib`i' = `i' if sib`i'[_n]!=.
bys pidkid: replace sib`i' = `i' if mis_sib`i'==1
sort pidkid syear
bys pidkid: gen householdsize_`i' = sib`i' + 2 if (pidkid!=. & pidmother!=. & pidfather==. & c_age==`i') | (pidkid!=. & pidmother==. & pidfather!=. & c_age==`i')
bys pidkid: replace householdsize_`i' = sib`i' + 3 if (pidkid!=. & pidmother!=. & pidfather!=. & c_age==`i')
bys pidkid: replace householdsize_`i' = householdsize_`i'[_n-1] if householdsize_`i'[_n]==.
label var householdsize_`i' "Household size when individual was `i' years old"
cap drop *sib`i'
}

egen householdsize = rmean(householdsize_0 - householdsize_15)
bys pidkid: gen mis_householdsize = 1 if householdsize==.
bys pidkid: replace mis_householdsize = 0 if householdsize!=.
bys pidkid: replace householdsize = 0 if mis_householdsize==1

**COMMENT: Create the time dummies
tab syear, gen(d_syear)
rename d_syear1 sy1984
label var sy1984 "Survey year dummy: 1984"
rename d_syear2 sy1985
label var sy1985 "Survey year dummy: 1985"
rename d_syear3 sy1986
label var sy1986 "Survey year dummy: 1986"
rename d_syear4 sy1987
label var sy1987 "Survey year dummy: 1987"
rename d_syear5 sy1988
label var sy1988 "Survey year dummy: 1988"
rename d_syear6 sy1989
label var sy1989 "Survey year dummy: 1989"
rename d_syear7 sy1990
label var sy1990 "Survey year dummy: 1990"
rename d_syear8 sy1991
label var sy1991 "Survey year dummy: 1991"
rename d_syear9 sy1992
label var sy1992 "Survey year dummy: 1992"
rename d_syear10 sy1993
label var sy1993 "Survey year dummy: 1993"
rename d_syear11 sy1994
label var sy1994 "Survey year dummy: 1994"
rename d_syear12 sy1995
label var sy1995 "Survey year dummy: 1995"
rename d_syear13 sy1996
label var sy1996 "Survey year dummy: 1996"
rename d_syear14 sy1997
label var sy1997 "Survey year dummy: 1997"
rename d_syear15 sy1998
label var sy1998 "Survey year dummy: 1998"
rename d_syear16 sy1999
label var sy1999 "Survey year dummy: 1999"
rename d_syear17 sy2000
label var sy2000 "Survey year dummy: 2000"
rename d_syear18 sy2001
label var sy2001 "Survey year dummy: 2001"
rename d_syear19 sy2002
label var sy2002 "Survey year dummy: 2002"
rename d_syear20 sy2003
label var sy2003 "Survey year dummy: 2003"
rename d_syear21 sy2004
label var sy2004 "Survey year dummy: 2004"
rename d_syear22 sy2005
label var sy2005 "Survey year dummy: 2005"
rename d_syear23 sy2006
label var sy2006 "Survey year dummy: 2006"
rename d_syear24 sy2007
label var sy2007 "Survey year dummy: 2007"
rename d_syear25 sy2008
label var sy2008 "Survey year dummy: 2008"
rename d_syear26 sy2009
label var sy2009 "Survey year dummy: 2009"
rename d_syear27 sy2010
label var sy2010 "Survey year dummy: 2010"
rename d_syear28 sy2011
label var sy2011 "Survey year dummy: 2011"
rename d_syear29 sy2012
label var sy2012 "Survey year dummy: 2012"
rename d_syear30 sy2013
label var sy2013 "Survey year dummy: 2013"
rename d_syear31 sy2014
label var sy2014 "Survey year dummy: 2014"
rename d_syear32 sy2015
label var sy2015 "Survey year dummy: 2015"
rename d_syear33 sy2016
label var sy2016 "Survey year dummy: 2016"
rename d_syear34 sy2017
label var sy2017 "Survey year dummy: 2017"
rename d_syear35 sy2018
label var sy2018 "Survey year dummy: 2018"
rename d_syear36 sy2019
label var sy2019 "Survey year dummy: 2019"

**Save the dataset
save anssam_soepv36eu.dta, replace
