*********************************************************************************
**Session: Regressions
**Author:  Michele Ubaldi
**Date:    December 17, 2024
*********************************************************************************
clear all

** Set in the right directory
cd "C:\Users\your_folder_path"
use anasam_soepv36eu.dta, clear

log using output, replace t

sort pidkid syear
xtset pidkid syear

xtdes
sum pidkid

**Note: Restrict the sample
*Drop younger than 18
drop if c_age<18
xtdes
sum pidkid
*Drop older than 31
drop if c_age>31
xtdes
sum pidkid

**Note: Keep only those who lived with both of their parents until the age of 15
count if c_living1!=15 & c_age>=17
count if c_living1>=15 & c_age>=17
count if c_living5==15 & c_age>=17
drop if c_living1<15
xtdes
sum pidkid

**Note: Keep individuals not having missings in outcomes
drop if mcs==. | pcs==.
xtdes
sum pidkid

***************************************
**** V A R I A B L E S   L I S T S ****
***************************************

**List 1
**Basic Covariates Kids - from Thomas Sieler & Milena Nikolova
*Age (ref. age 18)
global ages age19 age20 age21 age22 age23 age24 age25 age26 age27 age28 age30 age31
*Birthyear (ref. 2000)
global birfe by1984 by1985 by1986 by1987 by1988 by1989 by1990 by1991 by1992 by1993 by1994 by1995 by1996 by1997 by1998 by1999
*fem for sex
global cmig c_migra
*f_migra for paternal immigrational background
*Paternal age at birth (ref. Less than 20)
global fathakb df_akb2125 df_akb2630 df_akb3135 df_akb3640 df_akb41m df_akbm
*Paternal education level (ref. Less than HS)
global fatheduc df_eduhs df_eduter df_edum
*m_migra for maternal immigrational background
*Maternal age at birth (ref. Less than 20)
global mothakb dm_akb2125 dm_akb2630 dm_akb3135 dm_akb3640 dm_akb41m dm_akbm
*Maternal education level (ref. Less than HS)
global motheduc dm_eduhs dm_eduter dm_edum
global first fb misfb
*Lander where an individual was born (ref. West-Germany)
global birthstate beager
*Survey year (ref. 2004)
global surfe sy2002 sy2006 sy2008 sy2010 sy2012 sy2014 sy2016 sy2018
*global macrobist bnorth bsouth bcwest misland

**List 2
**Additional controls
*Family income quintile during treatment period (ref. 1st quintile - incqui02)
global incqui incqui01 incqui03 incqui04 incqui05 incqui06
global hhsize hhsz0
global hmsize hmsz0 mis_hmsz0
global sibli sib0
global momcumpre m_cumunem0 mis_m_cumunem0
global dadcumpre f_cumunem0 mis_f_cumunem0

**List 3
**Additional variables on job loss expectation (at individual's birth)
global dadjexlos f_jobexplo0 mis_f_jobexplo0
global momjexlos m_jobexplo0 mis_m_jobexplo0


**********************************************************************************************************
**********************************************************************************************************
*********************************************************************
*************** E S T I M A T I O N     R E S U L T S ***************
*********************************************************************

**********************************************************************************************************
** Standardize the health outcomes (MCS and PCS)
** Mental Component Summary scale
egen mmcs = mean(mcs), by(syear)
egen sdmcs = sd(mcs), by(syear)
gen stdmcs = (mcs - mmcs)/sdmcs
cap drop mmcs sdmcs

** Physical Component Summary scale
egen mpcs = mean(pcs), by(syear)
egen sdpcs = sd(pcs), by(syear)
gen stdpcs = (pcs - mpcs)/sdpcs
cap drop mpcs sdpcs
**********************************************************************************************************


****************
*** MATCHING ***
****************
*References: i) Paternal (Maternal) education <HS, ii) West Germany, iii) Paternal (Maternal) age at birth <20, iv) 1st family income quintile
*Age: 0-15, full sample
ebalance plant015 c_age fem c_migra beager f_migra df_edum df_eduhs df_eduter df_akbm df_akb2125 df_akb2630 df_akb3135 df_akb3640 df_akb41m m_migra dm_edum dm_eduhs dm_eduter dm_akbm dm_akb2125 dm_akb2630 dm_akb3135 dm_akb3640 dm_akb41m fb misf $incqui $sibli $dadcumpre $momcumpre if plant015!=. & exc015!=1, targets(2) tolerance(1) gen(ew015) keep(baltable015) rep

** Balancing performance
** COMMENT: We created Tables 3 and B.1, we computed the two following loops. Thereafter, we manually entered each result one by one in the tables.
**  i) Difference and bias
foreach var of varlist c_age fem c_migra beager f_migra df_edum df_eduhs df_eduter df_akbm df_akb2125 df_akb2630 df_akb3135 df_akb3640 df_akb41m m_migra dm_edum dm_eduhs dm_eduter dm_akbm dm_akb2125 dm_akb2630 dm_akb3135 dm_akb3640 dm_akb41m fb misf $incqui $sibli $dadcumpre $momcumpre {
	des `var'

	** Controls pre-matching
	sum `var' if plant015==0 & ew015!=.
	scalar mu_con_pre = round(r(mean), 0.001)
	scalar var_con_pre = round(r(Var), 0.001)
	
	** Controls units post-matching
	sum `var' [aweight=ew015] if plant015==0 & ew015!=.
	scalar mu_con_post = round(r(mean), 0.001)
	scalar var_con_post = round(r(Var), 0.001)
	
	** Treated units
	sum `var' if plant015==1 & ew015!=.
	scalar mu_tre = round(r(mean), 0.001)
	scalar var_tre = round(r(Var), 0.001)
	
	** Difference
	di "Difference in mean pre-matching is: "abs(mu_tre - mu_con_pre)
	di "Difference in mean post-matching is: "abs(mu_tre - mu_con_post)
	di "Difference in variance pre-matching is: "abs(var_tre - var_con_pre)
	di "Difference in variance post-matching is: "abs(var_tre - var_con_post)
	
	** Bias
	di "Bias in mean pre-matching is: "round(abs(mu_tre - mu_con_pre)/mu_tre*100, 0.001)
	di "Bias in mean post-matching is: "round(abs(mu_tre - mu_con_post)/mu_tre*100, 0.001)
	di "Bias in variance pre-matching is: "round(abs(var_tre - var_con_pre)/(var_tre)*100, 0.001)
	di "Bias in variance post-matching is: "round(abs(var_tre - var_con_post)/(var_tre)*100, 0.001)
}

** ii) Mean and variance equality tests
foreach var of varlist c_age fem c_migra beager f_migra df_edum df_eduhs df_eduter df_akbm df_akb2125 df_akb2630 df_akb3135 df_akb3640 df_akb41m m_migra dm_edum dm_eduhs dm_eduter dm_akbm dm_akb2125 dm_akb2630 dm_akb3135 dm_akb3640 dm_akb41m fb misf $incqui $sibli $dadcumpre $momcumpre {
	des `var'

	** Controls pre-matching
	qui sum `var' if plant015==0 & ew015!=.
	qui local mu_con_pre = r(mean)
	qui local se_con_pre = r(sd)
	
	** Controls units post-matching
	qui sum `var' [aweight=ew015] if plant015==0 & ew015!=.
	qui local mu_con_post = r(mean)
	qui local se_con_post = r(sd)
	
	** Treated units
	qui sum `var' if plant015==1 & ew015!=.
	qui local mu_tre = r(mean)
	qui local se_tre = r(sd)
	
	** Mean test
	ttesti 208 `mu_tre' `se_tre' 4614 `mu_con_pre' `se_con_pre'
	ttesti 208 `mu_tre' `se_tre' 4614 `mu_con_post' `se_con_post'
	
	** Variance test
	sdtesti 208 `mu_tre' `se_tre' 4614 `mu_con_pre' `se_con_pre'
	sdtesti 208 `mu_tre' `se_tre' 4614 `mu_con_post' `se_con_post'
}


*********************************************
*** PARAMETRIC ESTIMATION - DOUBLY ROBUST ***
*********************************************

*Model 1 - No household characteristics, and descriptive statistics (plus plots and graphs)
*0-15, full sample
xtregre2 stdmcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre [aweight=ew015] if plant015!=., i(pidkid)
outreg2 using plant_cum_stdmcs015.xls, aster e(r2_o) bdec(3) replace
xtregre2 stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre [aweight=ew015] if plant015!=., i(pidkid)
**Note: Create e(sample) variable from main analysis
gen main015 = 1 if e(sample)
corr stdmcs stdpcs c_lifesat if main015==1
***Descriptive statistics
xtdes if main015==1
xtdes if main015==1 & plant015==1
**COMMENT: We have 2195 individuals overall, 75 of which are treated
tab plant015 if main015==1
tab plantdad015 if main015==1
tab plantmom015 if main015==1
**COMMENT: We 5763 individual-year treated observations of which: i) 5555 are from paternal and ii) 208 are from maternal
sum std*cs if main015==1
bys plant015: sum std*cs if main015==1
**COMMENT: MCS mean values is -0.0712458. Splitting for plant closure we have: i) -0.0709116 for controls and ii) -0.0801724 for treated
**COMMENT: PCS mean values is -0.0266652. Splitting for plant closure we have: i) -0.0155986 for controls and ii) -0.3222171 for treated
**Graphs
   twoway (hist stdmcs if plant015==0 & main015==1, blcolor("blue") bfcolor(none) bin(10) legend(label(1 "Control units"))) (hist stdmcs if plant015==1 & main015==1, blcolor("red") bfcolor(none) bin(10) legend(label(2 "Treated units")))
   graph save Graph "C:\Users\your_folder_path\tables\stdmcs015.gph", replace
   twoway (hist stdpcs if plant015==0 & main015==1, blcolor("blue") bfcolor(none) bin(10) legend(label(1 "Control units"))) (hist stdpcs if plant015==1 & main015==1, blcolor("red") bfcolor(none) bin(10) legend(label(2 "Treated units")))
   graph save Graph "C:\Users\your_folder_path\tables\stdpcs015.gph", replace
**Tables
   estpost sum stdmcs stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb df_akb20l $fatheduc df_edulh m_migra $mothakb dm_akb20l $motheduc dm_edulh $birthstate bweger $surfe sy2004 $birfe by2000 $incqui incqui02 $sibli $dadcumpre $momcumpre if main015==1
   esttab using "C:\Users\your_folder_path\tables\des_std015.csv", cells("mean(fmt(3)) sd(fmt(3)) min(fmt(3)) max(fmt(3))") nomtitles numbers replace
   estpost sum stdmcs stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb df_akb20l $fatheduc df_edulh m_migra $mothakb dm_akb20l $motheduc dm_edulh $birthstate bweger $surfe sy2004 $birfe by2000 $incqui incqui02 $sibli $dadcumpre $momcumpre if main015==1 & plant015==1
   esttab using "C:\Users\your_folder_path\tables\des_std_trea015.csv", cells("mean(fmt(3)) sd(fmt(3)) min(fmt(3)) max(fmt(3))") nomtitles numbers replace
   estpost sum stdmcs stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb df_akb20l $fatheduc df_edulh m_migra $mothakb dm_akb20l $motheduc dm_edulh $birthstate bweger $surfe sy2004 $birfe by2000 $incqui incqui02 $sibli $dadcumpre $momcumpre if main015==1 & plant015==0
   esttab using "C:\Users\your_folder_path\tables\des_std_cont015.csv", cells("mean(fmt(3)) sd(fmt(3)) min(fmt(3)) max(fmt(3))") nomtitles numbers replace
bys plant015: sum stdmcs stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb df_akb20l $fatheduc df_edulh m_migra $mothakb dm_akb20l $motheduc df_edulh $birthstate bweger $surfe sy2004 $birfe by2000 $incqui incqui02 $sibli $dadcumpre $momcumpre if main015==1
qui xtregre2 stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre [aweight=ew015] if plant015!=., i(pidkid)
outreg2 using plant_cum_stdpcs015.xls, aster e(r2_o) bdec(3) replace


*Model 2 - With household characteristics
*0-15, full sample
xtregre2 stdmcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize [aweight=ew015] if plant015!=., i(pidkid)
outreg2 using plant_cum_stdmcs015.xls, aster e(r2_o) bdec(3) append
xtregre2 stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize [aweight=ew015] if plant015!=., i(pidkid)
outreg2 using plant_cum_stdpcs015.xls, aster e(r2_o) bdec(3) append


*Model 3 - With lagged job loss expectations
*0-15, full sample
xtregre2 stdmcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=., i(pidkid)
outreg2 using plant_cum_stdmcs015.xls, aster e(r2_o) bdec(3) append
xtregre2 stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=., i(pidkid)
outreg2 using plant_cum_stdpcs015.xls, aster e(r2_o) bdec(3) append


** Table 5 - Pooled OLS estimates
*Model 1
reg stdmcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre [aweight=ew015] if plant015!=., vce(cluster pidkid)
reg stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre [aweight=ew015] if plant015!=., vce(cluster pidkid)

*Model 2
reg stdmcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize [aweight=ew015] if plant015!=., vce(cluster pidkid)
reg stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize [aweight=ew015] if plant015!=., vce(cluster pidkid)

*Model 3
reg stdmcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=., vce(cluster pidkid)
reg stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=., vce(cluster pidkid)


** Table 5 - Only with non broken families
*Model 1
xtregre2 stdmcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre [aweight=ew015] if plant015!=. & merge_nonbroken==3, i(pidkid)
xtregre2 stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre [aweight=ew015] if plant015!=. & merge_nonbroken==3, i(pidkid)

*Model 2
xtregre2 stdmcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize [aweight=ew015] if plant015!=. & merge_nonbroken==3, i(pidkid)
xtregre2 stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize [aweight=ew015] if plant015!=. & merge_nonbroken==3, i(pidkid)

*Model 3
xtregre2 stdmcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=. & merge_nonbroken==3, i(pidkid)
xtregre2 stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=. & merge_nonbroken==3, i(pidkid)

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////
***MEDIATING CHANNELLES, HETEROGENEITY ANAYLISIS AND ROBUSTNESS CHECKS
////////////////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////
***MEDIATING CHANNELS: Alcohol consumption
**Note: Store the results in the right directory
cd "C:\Users\your_folder_path\tables\media"
**Note: Model (3), includes job loss expectation 
*0-15, full sample
xtregre2 sevalcon plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if main015==1, i(pidkid)
count if e(sample) & plant015==1
sum sevalcon if e(sample) & plant015==1
outreg2 using plant_media_sevalcon.xls, aster e(r2_o) bdec(3) replace

********************************************************************************
***MEDIATING CHANNELS: Probability of being a current smoker
**Note: Model (3), includes job loss expectation 
*0-15, full sample
xtregre2 c_smoke plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if main015==1, i(pidkid)
count if e(sample) & plant015==1
sum c_smoke if e(sample) & plant015==1
outreg2 using plant_media_smoke.xls, aster e(r2_o) bdec(3) replace

********************************************************************************
***MEDIATING CHANNELS: Probability of being obese (BMI>30)
**Note: Model (3), includes job loss expectation 
*0-15, full sample
xtregre2 obese plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if main015==1, i(pidkid)
count if e(sample) & plant015==1
sum obese if e(sample) & plant015==1
outreg2 using plant_media_obese.xls, aster e(r2_o) bdec(3) replace

log close

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////
********************************************************************************
***HETEROGENEITY for: Splitting treatment group homogeneously depending on treatment age
**Note: Store the results in the right directory
cd "C:\Users\your_folder_path\tables\hetero\ages"

preserve
egen plant08 = rmax(plantc0-plantc8)
des plant08
count if plant08==1 & main015==1
egen plant915 = rmax(plantc9-plantc15)
des plant915
count if plant915==1 & main015==1

*Subgroup treatment variables
sort pidkid syear
bys pidkid: gen plant015_08 = 0 if main015==1
bys pidkid: replace plant015_08 = 1 if main015==1 & plant08==1
bys pidkid: gen plant015_915 = 0 if main015==1
bys pidkid: replace plant015_915 = 1 if main015==1 & plant915==1


*Generate list
global blockall_to_include c_age fem fb misfb c_migra f_migra df_akb2125 df_akb2630 df_akb3135 df_akb3640 df_akb41m df_akbm df_eduhs df_eduter df_edum m_migra dm_akb2125 dm_akb2630 dm_akb3135 dm_akb3640 dm_akb41m dm_akbm dm_eduhs dm_eduter dm_edum beager sy2002 sy2006 sy2008 sy2010 sy2012 sy2014 sy2016 sy2018 by1984 by1985 by1986 by1987 by1988 by1989 by1990 by1991 by1992 by1993 by1994 by1995 by1996 by1997 by1998 by1999 incqui01 incqui03 incqui04 incqui05 incqui06 sib0 f_cumunem0 mis_f_cumunem0 m_cumunem0 mis_m_cumunem0 hhsz0 hmsz0 mis_hmsz0 f_jobexplo0 mis_f_jobexplo0 m_jobexplo0 mis_m_jobexplo0

*Regression
	log using plant015_08915, replace t
	*0-15
	*Mental health
		xtregre2 stdmcs plant015_08 plant015_915 unempatage015 $blockall_to_include [aweight=ew015] if plant015!=., i(pidkid)
		count if plant015_08==1 & e(sample)
		count if plant015_915==1 & e(sample)
		outreg2 using plant08915_cum_stdmcs015.xls, aster e(r2_o) bdec(3) replace
		*Tests
		test _coef[plant015_08]== _coef[plant015_915]
	*Physical health
		xtregre2 stdpcs plant015_08 plant015_915 unempatage015 $blockall_to_include [aweight=ew015] if plant015!=., i(pidkid)
		count if plant015_08==1 & e(sample)
		count if plant015_915==1 & e(sample)
		outreg2 using plant08915_cum_stdpcs015.xls, aster e(r2_o) bdec(3) replace
		*Tests
		test _coef[plant015_08]== _coef[plant015_915]
	log close
restore

********************************************************************************
***HETEROGENEITY for: PATERNAL vs MATERNAL
**Note: Store the results in the right directory
cd "C:\Users\your_folder_path\tables\hetero\motpat"
preserve
	log using matpat, replace t
	foreach var of varlist plantmom015 plantdad015 {
	clonevar `var'_new = `var'
	}
	bys pidkid: replace plantmom015_new = plant015 if main015==1 & plantmom015==. & plantdad015!=.
	bys pidkid: replace plantdad015_new = plant015 if main015==1 & plantdad015==. & plantmom015!=.

	**Note: Model (3), includes job loss expectation 
		*MCS
		xtregre2 stdmcs plantdad015_new plantmom015_new unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=., i(pidkid)
		count if plantdad015_new==1 & e(sample)
		count if plantmom015_new==1 & e(sample)
			*Table
			outreg2 using plantsep_cum_stdmcs015.xls, aster e(r2_o) bdec(3) replace
			*Equality test on the coefficients
			test _coef[plantdad015_new]== _coef[plantmom015_new]
		*PCS
		xtregre2 stdpcs plantdad015_new plantmom015_new unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=., i(pidkid)
		count if plantdad015_new==1 & e(sample)
		count if plantmom015_new==1 & e(sample)
			*Table
			outreg2 using plantsep_cum_stdpcs015.xls, aster e(r2_o) bdec(3) replace
		*Equality test on the coefficients
		test _coef[plantdad015_new]== _coef[plantmom015_new]
	log close
restore

********************************************************************************
***HETEROGENEITY for: MEN vs WOMEN
**Note: Store the results in the right directory
cd "C:\Users\your_folder_path\tables\hetero\dauson"

*Interact variable
preserve
gen men = 1 if fem==0
replace men = 0 if fem==1
gen plant015_fem = plant015*fem
gen plant015_men = plant015*men

*Generate list
global blockall_to_include c_age fem fb misfb c_migra f_migra df_akb2125 df_akb2630 df_akb3135 df_akb3640 df_akb41m df_akbm df_eduhs df_eduter df_edum m_migra dm_akb2125 dm_akb2630 dm_akb3135 dm_akb3640 dm_akb41m dm_akbm dm_eduhs dm_eduter dm_edum beager sy2002 sy2006 sy2008 sy2010 sy2012 sy2014 sy2016 sy2018 by1984 by1985 by1986 by1987 by1988 by1989 by1990 by1991 by1992 by1993 by1994 by1995 by1996 by1997 by1998 by1999 incqui01 incqui03 incqui04 incqui05 incqui06 sib0 f_cumunem0 mis_f_cumunem0 m_cumunem0 mis_m_cumunem0 hhsz0 hmsz0 mis_hmsz0 f_jobexplo0 mis_f_jobexplo0 m_jobexplo0 mis_m_jobexplo0

*Regression
	log using dauson, replace t
	*0-15
	*Mental health
		xtregre2 stdmcs plant015_men plant015_fem unempatage015 $blockall_to_include [aweight=ew015] if plant015!=., i(pidkid)
		count if plant015_men==1 & e(sample)
		count if plant015_fem==1 & e(sample)
		outreg2 using plantdauson_cum_stdmcs015.xls, aster e(r2_o) bdec(3) replace
		*Tests
		test _coef[plant015_men]== _coef[plant015_fem]
	*Physical health
		xtregre2 stdpcs plant015_men plant015_fem unempatage015 $blockall_to_include [aweight=ew015] if plant015!=., i(pidkid)
		count if plant015_men==1 & e(sample)
		count if plant015_fem==1 & e(sample)
		outreg2 using plantdauson_cum_stdpcs015.xls, aster e(r2_o) bdec(3) replace
		*Tests
		test _coef[plant015_men]== _coef[plant015_fem]
	log close
restore


///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
***HETEROGENEITY for: EAST and WEST Germany
*Store the results in the right directory
cd "C:\Users\your_folder_path\tables\hetero\eastwest"

*Interact variable
preserve
gen plant015_east = plant015*beager
gen plant015_west = plant015*bweger

*Generate list
global blockall_to_include c_age fem fb misfb c_migra f_migra df_akb2125 df_akb2630 df_akb3135 df_akb3640 df_akb41m df_akbm df_eduhs df_eduter df_edum m_migra dm_akb2125 dm_akb2630 dm_akb3135 dm_akb3640 dm_akb41m dm_akbm dm_eduhs dm_eduter dm_edum beager sy2002 sy2006 sy2008 sy2010 sy2012 sy2014 sy2016 sy2018 by1984 by1985 by1986 by1987 by1988 by1989 by1990 by1991 by1992 by1993 by1994 by1995 by1996 by1997 by1998 by1999 incqui01 incqui03 incqui04 incqui05 incqui06 sib0 f_cumunem0 mis_f_cumunem0 m_cumunem0 mis_m_cumunem0 hhsz0 hmsz0 mis_hmsz0 f_jobexplo0 mis_f_jobexplo0 m_jobexplo0 mis_m_jobexplo0

*Regression
	log using eastwest, replace t
	*0-15
	*Mental health
		xtregre2 stdmcs plant015_west plant015_east unempatage015 $blockall_to_include [aweight=ew015] if plant015!=., i(pidkid)
		count if plant015_west==1 & e(sample)
		count if plant015_east==1 & e(sample)
		outreg2 using planteastwest_cum_stdmcs015.xls, aster e(r2_o) bdec(3) replace
		*Tests
		test _coef[plant015_west]== _coef[plant015_east]
	*Physical health
		xtregre2 stdpcs plant015_west plant015_east unempatage015 $blockall_to_include [aweight=ew015] if plant015!=., i(pidkid)
		count if plant015_west==1 & e(sample)
		count if plant015_east==1 & e(sample)
		outreg2 using planteastwest_cum_stdpcs015.xls, aster e(r2_o) bdec(3) replace
		*Tests
		test _coef[plant015_west]== _coef[plant015_east]
	log close
restore

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
***HETEROGENEITY for: Split sample in before (after) German labor market reform (year, 2003)
**Note: Store the results in the right directory
cd "C:\Users\your_folder_path\tables\hetero\reform"

*Interact variable
preserve
gen prerefo = 1 if ypc<=2002
replace prerefo = 0 if ypc>2002
gen postrefo = 1 if ypc>2002
replace postrefo = 0 if ypc<=2002
gen plant015_prereform = plant015*prerefo
gen plant015_postreform = plant015*postrefo

*Generate list
global blockall_to_include c_age fem fb misfb c_migra f_migra df_akb2125 df_akb2630 df_akb3135 df_akb3640 df_akb41m df_akbm df_eduhs df_eduter df_edum m_migra dm_akb2125 dm_akb2630 dm_akb3135 dm_akb3640 dm_akb41m dm_akbm dm_eduhs dm_eduter dm_edum beager sy2002 sy2006 sy2008 sy2010 sy2012 sy2014 sy2016 sy2018 by1984 by1985 by1986 by1987 by1988 by1989 by1990 by1991 by1992 by1993 by1994 by1995 by1996 by1997 by1998 by1999 incqui01 incqui03 incqui04 incqui05 incqui06 sib0 f_cumunem0 mis_f_cumunem0 m_cumunem0 mis_m_cumunem0 hhsz0 hmsz0 mis_hmsz0 f_jobexplo0 mis_f_jobexplo0 m_jobexplo0 mis_m_jobexplo0

*Regression
	log using reform, replace t
	*0-15
	*Mental health
		xtregre2 stdmcs plant015_prereform plant015_postreform unempatage015 $blockall_to_include [aweight=ew015] if plant015!=., i(pidkid)
		count if plant015_prereform==1 & e(sample)
		count if plant015_postreform==1 & e(sample)
		outreg2 using plantreform_cum_stdmcs015.xls, aster e(r2_o) bdec(3) replace
		*Tests
		test _coef[plant015_prereform]== _coef[plant015_postreform]
		*Physical health
		xtregre2 stdpcs plant015_prereform plant015_postreform unempatage015 $blockall_to_include [aweight=ew015] if plant015!=., i(pidkid)
		count if plant015_prereform==1 & e(sample)
		count if plant015_postreform==1 & e(sample)
		outreg2 using plantreform_cum_stdpcs015.xls, aster e(r2_o) bdec(3) replace
		*Tests
		test _coef[plant015_prereform]== _coef[plant015_postreform]
	log close
restore

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////
***ROBUSTNESS for: Alternative matching procedures (IPWRA)
**Note: Store the results in the right directory
cd "C:\Users\your_folder_path\tables\robustness\altmatch"

*0-15, whole sample
global x1_015 c_age fem c_migra beager f_migra df_eduhs df_akb2125 df_akb2630 df_akb3135 df_akb3640 df_akb41m m_migra dm_eduhs dm_akb2125 dm_akb2630 dm_akb3135 dm_akb3640 fb misf incqui01 incqui03 incqui04 incqui05 $sibli $dadcumpre $momcumpre
global x2_015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos
foreach var of varlist stdmcs stdpcs {
	**COMMENT: Inverse Probability Weighting Regression Adjusted (IPWRA)
	preserve
	logit plant015 $x1_015 if `var'!=. & exc015!=1
	**COMMENT: Predict the probabilities
	predict pr_`var'_015 if `var'!=. & exc015!=1, pr
	**COMMENT: Restrict on common support and check the overlap condition
	sum pr_`var'_015 if plant015!=., det
	sum pr_`var'_015 if plant015==0
	sum pr_`var'_015 if plant015==1
	**COMMENT: Overlap condition not met in the upper bound, check how number of treated that exceed the controls maximum
	drop if plant015==.
	count if pr_`var'_015>0.5629019 & plant015==1 & main015==1
	**COMMENT: They are only three (1.44% of the treated group); drop them
	drop if pr_`var'_015>0.5629019 & plant015==1 & main015==1
	gen pippo_`var'_015=(pr_`var'_015/(1-pr_`var'_015)) if plant015==0
	**COMMENT: Create the probability for the controls
	egen prco_`var'_015=mean(pippo_`var'_015) if plant015==0
	cap drop pippo_`var'_015
	cap drop wei
	**COMMENT: Create the weight for the treated
	gen wei_`var'_015 = 1 if plant015==1
	**COMMENT: Create the weight for the regression command
	replace wei_`var'_015 = (pr_`var'_015/(1-pr_`var'_015))/prco_`var'_015 if plant015==0 /*to be used in Stata with the option [w=wei]*/
	**COMMENT: Create the weight for manually do it
	gen mwei_`var'_015 = wei_`var'_015^0.5 

	*Regression adjustedment
	xtregre2 `var' plant015 $x2_015 [aweight=mwei_`var'_015], i(pidkid) 
	outreg2 using atlmatch_cum_`var'015.xls, aster e(r2_o) bdec(3) replace
	restore
}

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
***APPENDIX ROBUSTNESS for: Randomly selecting out one of the waves
**Note: Store the results in the right directory
cd "C:\Users\your_folder_path\tables\robustness\waves"

*Age: 0-15
**Note: Model (3), includes job loss expectation 
**		Exclude the first wave and create the table so that following results can be appended
	*Mental health
		log using waves_stdmcs015, replace t
		qui xtregre2 stdmcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=. & syear!=2002, i(pidkid)
		**Table
		outreg2 using waves_cum_stdmcs015.xls, aster e(r2_o) bdec(3) replace
		**		Create the loop for the remaining waves
		forvalues i = 2004(2)2018{
			qui xtregre2 stdmcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=. & syear!=`i', i(pidkid)
			outreg2 using waves_cum_stdmcs015.xls, aster e(r2_o) bdec(3) append
		}
		*Multiple testing with Romano and Wolf (2005), `Stepwise multiple testing as formalized data snooping', Econometrica
		rwolf2 (xtregre2 stdmcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=. & syear!=2002, i(pidkid)) (xtregre2 stdmcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=. & syear!=2004, i(pidkid)) (xtregre2 stdmcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=. & syear!=2006, i(pidkid)) (xtregre2 stdmcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=. & syear!=2008, i(pidkid)) (xtregre2 stdmcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=. & syear!=2010, i(pidkid)) (xtregre2 stdmcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=. & syear!=2012, i(pidkid)) (xtregre2 stdmcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=. & syear!=2014, i(pidkid)) (xtregre2 stdmcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=. & syear!=2016, i(pidkid)) (xtregre2 stdmcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=. & syear!=2018, i(pidkid)), indepvars(plant015, plant015, plant015, plant015, plant015, plant015, plant015, plant015, plant015) seed(1) reps(1000)
		log close
		
	*Physical health
		log using waves_stdpcs015, replace t
		qui xtregre2 stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=. & syear!=2002, i(pidkid)
		**Table
		outreg2 using waves_cum_stdpcs015.xls, aster e(r2_o) bdec(3) replace
		**		Create the loop for the remaining waves
		forvalues i = 2004(2)2018{
			qui xtregre2 stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=. & syear!=`i', i(pidkid)
			outreg2 using waves_cum_stdpcs015.xls, aster e(r2_o) bdec(3) append
		}		
		*Multiple testing with Romano and Wolf (2005), `Stepwise multiple testing as formalized data snooping', Econometrica
		rwolf2 (xtregre2 stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=. & syear!=2002, i(pidkid)) (xtregre2 stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=. & syear!=2004, i(pidkid)) (xtregre2 stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=. & syear!=2006, i(pidkid)) (xtregre2 stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=. & syear!=2008, i(pidkid)) (xtregre2 stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=. & syear!=2010, i(pidkid)) (xtregre2 stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=. & syear!=2012, i(pidkid)) (xtregre2 stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=. & syear!=2014, i(pidkid)) (xtregre2 stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=. & syear!=2016, i(pidkid)) (xtregre2 stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=. & syear!=2018, i(pidkid)), indepvars(plant015, plant015, plant015, plant015, plant015, plant015, plant015, plant015, plant015) seed(1) reps(1000)
		log close

********************************************************************************
** Sanity check on waves
*Isolate samples removing each time a wave
forvalues i = 2002(2)2018 {
	preserve
	drop if syear==`i'
	gen blockno`i' = 1
	save "C:\Users\your_folder_path\tempno`i'.dta", replace
restore
}
*Append blocks
preserve
gen blockall = 1
forvalues i = 2002(2)2018 {
	append using "C:\Users\your_folder_path\tempno`i'"
	cap erase "C:\Users\your_folder_path\tempno`i'"
}
save "C:\Users\your_folder_path\sanitycheck.dta", replace
restore

*Interact variables
preserve
use "C:\Users\your_folder_path\sanitycheck.dta", clear

replace blockall = 0 if blockall==.
forvalues i = 2002(2)2018 {
	replace blockno`i' = 0 if blockno`i'==.
}

gen block = 0 if blockall==1
replace block = 1 if blockno2002==1
replace block = 2 if blockno2004==1
replace block = 3 if blockno2006==1
replace block = 4 if blockno2008==1
replace block = 5 if blockno2010==1
replace block = 6 if blockno2012==1
replace block = 7 if blockno2014==1
replace block = 8 if blockno2016==1
replace block = 9 if blockno2018==1

forvalues i = 2002(2)2018{
	foreach var of varlist plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos {
		gen `var'_block`i' = `var'*blockno`i'
	}
}

gen double pidkid_blockno = pidkid*1000 + blockall if blockall==1
replace pidkid_blockno = pidkid*1000 + blockno2002 + 1 if blockno2002==1
replace pidkid_blockno = pidkid*1000 + blockno2004 + 2 if blockno2004==1
replace pidkid_blockno = pidkid*1000 + blockno2006 + 3 if blockno2006==1
replace pidkid_blockno = pidkid*1000 + blockno2008 + 4 if blockno2008==1
replace pidkid_blockno = pidkid*1000 + blockno2010 + 5 if blockno2010==1
replace pidkid_blockno = pidkid*1000 + blockno2012 + 6 if blockno2012==1
replace pidkid_blockno = pidkid*1000 + blockno2014 + 7 if blockno2014==1
replace pidkid_blockno = pidkid*1000 + blockno2016 + 8 if blockno2016==1
replace pidkid_blockno = pidkid*1000 + blockno2018 + 9 if blockno2018==1

*Generate list
global blockall_to_include c_age fem fb misfb c_migra f_migra df_akb2125 df_akb2630 df_akb3135 df_akb3640 df_akb41m df_akbm df_eduhs df_eduter df_edum m_migra dm_akb2125 dm_akb2630 dm_akb3135 dm_akb3640 dm_akb41m dm_akbm dm_eduhs dm_eduter dm_edum beager sy2002 sy2006 sy2008 sy2010 sy2012 sy2014 sy2016 sy2018 by1984 by1985 by1986 by1987 by1988 by1989 by1990 by1991 by1992 by1993 by1994 by1995 by1996 by1997 by1998 by1999 incqui01 incqui03 incqui04 incqui05 incqui06 sib0 f_cumunem0 mis_f_cumunem0 m_cumunem0 mis_m_cumunem0 hhsz0 hmsz0 mis_hmsz0 f_jobexplo0 mis_f_jobexplo0 m_jobexplo0 mis_m_jobexplo0
global block2002_to_include c_age_block2002 fem_block2002 fb_block2002 misfb_block2002 c_migra_block2002 f_migra_block2002 df_akb2125_block2002 df_akb2630_block2002 df_akb3135_block2002 df_akb3640_block2002 df_akb41m_block2002 df_akbm_block2002 df_eduhs_block2002 df_eduter_block2002 df_edum_block2002 m_migra_block2002 dm_akb2125_block2002 dm_akb2630_block2002 dm_akb3135_block2002 dm_akb3640_block2002 dm_akb41m_block2002 dm_akbm_block2002 dm_eduhs_block2002 dm_eduter_block2002 dm_edum_block2002 beager_block2002 sy2002_block2002 sy2006_block2002 sy2008_block2002 sy2010_block2002 sy2012_block2002 sy2014_block2002 sy2016_block2002 sy2018_block2002 by1984_block2002 by1985_block2002 by1986_block2002 by1987_block2002 by1988_block2002 by1989_block2002 by1990_block2002 by1991_block2002 by1992_block2002 by1993_block2002 by1994_block2002 by1995_block2002 by1996_block2002 by1997_block2002 by1998_block2002 by1999_block2002 incqui01_block2002 incqui03_block2002 incqui04_block2002 incqui05_block2002 incqui06_block2002 sib0_block2002 f_cumunem0_block2002 mis_f_cumunem0_block2002 m_cumunem0_block2002 mis_m_cumunem0_block2002 hhsz0_block2002 hmsz0_block2002 mis_hmsz0_block2002 f_jobexplo0_block2002 mis_f_jobexplo0_block2002 m_jobexplo0_block2002 mis_m_jobexplo0_block2002
global block2004_to_include c_age_block2004 fem_block2004 fb_block2004 misfb_block2004 c_migra_block2004 f_migra_block2004 df_akb2125_block2004 df_akb2630_block2004 df_akb3135_block2004 df_akb3640_block2004 df_akb41m_block2004 df_akbm_block2004 df_eduhs_block2004 df_eduter_block2004 df_edum_block2004 m_migra_block2004 dm_akb2125_block2004 dm_akb2630_block2004 dm_akb3135_block2004 dm_akb3640_block2004 dm_akb41m_block2004 dm_akbm_block2004 dm_eduhs_block2004 dm_eduter_block2004 dm_edum_block2004 beager_block2004 sy2002_block2004 sy2006_block2004 sy2008_block2004 sy2010_block2004 sy2012_block2004 sy2014_block2004 sy2016_block2004 sy2018_block2004 by1984_block2004 by1985_block2004 by1986_block2004 by1987_block2004 by1988_block2004 by1989_block2004 by1990_block2004 by1991_block2004 by1992_block2004 by1993_block2004 by1994_block2004 by1995_block2004 by1996_block2004 by1997_block2004 by1998_block2004 by1999_block2004 incqui01_block2004 incqui03_block2004 incqui04_block2004 incqui05_block2004 incqui06_block2004 sib0_block2004 f_cumunem0_block2004 mis_f_cumunem0_block2004 m_cumunem0_block2004 mis_m_cumunem0_block2004 hhsz0_block2004 hmsz0_block2004 mis_hmsz0_block2004 f_jobexplo0_block2004 mis_f_jobexplo0_block2004 m_jobexplo0_block2004 mis_m_jobexplo0_block2004
global block2006_to_include c_age_block2006 fem_block2006 fb_block2006 misfb_block2006 c_migra_block2006 f_migra_block2006 df_akb2125_block2006 df_akb2630_block2006 df_akb3135_block2006 df_akb3640_block2006 df_akb41m_block2006 df_akbm_block2006 df_eduhs_block2006 df_eduter_block2006 df_edum_block2006 m_migra_block2006 dm_akb2125_block2006 dm_akb2630_block2006 dm_akb3135_block2006 dm_akb3640_block2006 dm_akb41m_block2006 dm_akbm_block2006 dm_eduhs_block2006 dm_eduter_block2006 dm_edum_block2006 beager_block2006 sy2002_block2006 sy2006_block2006 sy2008_block2006 sy2010_block2006 sy2012_block2006 sy2014_block2006 sy2016_block2006 sy2018_block2006 by1984_block2006 by1985_block2006 by1986_block2006 by1987_block2006 by1988_block2006 by1989_block2006 by1990_block2006 by1991_block2006 by1992_block2006 by1993_block2006 by1994_block2006 by1995_block2006 by1996_block2006 by1997_block2006 by1998_block2006 by1999_block2006 incqui01_block2006 incqui03_block2006 incqui04_block2006 incqui05_block2006 incqui06_block2006 sib0_block2006 f_cumunem0_block2006 mis_f_cumunem0_block2006 m_cumunem0_block2006 mis_m_cumunem0_block2006 hhsz0_block2006 hmsz0_block2006 mis_hmsz0_block2006 f_jobexplo0_block2006 mis_f_jobexplo0_block2006 m_jobexplo0_block2006 mis_m_jobexplo0_block2006
global block2008_to_include c_age_block2008 fem_block2008 fb_block2008 misfb_block2008 c_migra_block2008 f_migra_block2008 df_akb2125_block2008 df_akb2630_block2008 df_akb3135_block2008 df_akb3640_block2008 df_akb41m_block2008 df_akbm_block2008 df_eduhs_block2008 df_eduter_block2008 df_edum_block2008 m_migra_block2008 dm_akb2125_block2008 dm_akb2630_block2008 dm_akb3135_block2008 dm_akb3640_block2008 dm_akb41m_block2008 dm_akbm_block2008 dm_eduhs_block2008 dm_eduter_block2008 dm_edum_block2008 beager_block2008 sy2002_block2008 sy2006_block2008 sy2008_block2008 sy2010_block2008 sy2012_block2008 sy2014_block2008 sy2016_block2008 sy2018_block2008 by1984_block2008 by1985_block2008 by1986_block2008 by1987_block2008 by1988_block2008 by1989_block2008 by1990_block2008 by1991_block2008 by1992_block2008 by1993_block2008 by1994_block2008 by1995_block2008 by1996_block2008 by1997_block2008 by1998_block2008 by1999_block2008 incqui01_block2008 incqui03_block2008 incqui04_block2008 incqui05_block2008 incqui06_block2008 sib0_block2008 f_cumunem0_block2008 mis_f_cumunem0_block2008 m_cumunem0_block2008 mis_m_cumunem0_block2008 hhsz0_block2008 hmsz0_block2008 mis_hmsz0_block2008 f_jobexplo0_block2008 mis_f_jobexplo0_block2008 m_jobexplo0_block2008 mis_m_jobexplo0_block2008
global block2010_to_include c_age_block2010 fem_block2010 fb_block2010 misfb_block2010 c_migra_block2010 f_migra_block2010 df_akb2125_block2010 df_akb2630_block2010 df_akb3135_block2010 df_akb3640_block2010 df_akb41m_block2010 df_akbm_block2010 df_eduhs_block2010 df_eduter_block2010 df_edum_block2010 m_migra_block2010 dm_akb2125_block2010 dm_akb2630_block2010 dm_akb3135_block2010 dm_akb3640_block2010 dm_akb41m_block2010 dm_akbm_block2010 dm_eduhs_block2010 dm_eduter_block2010 dm_edum_block2010 beager_block2010 sy2002_block2010 sy2006_block2010 sy2008_block2010 sy2010_block2010 sy2012_block2010 sy2014_block2010 sy2016_block2010 sy2018_block2010 by1984_block2010 by1985_block2010 by1986_block2010 by1987_block2010 by1988_block2010 by1989_block2010 by1990_block2010 by1991_block2010 by1992_block2010 by1993_block2010 by1994_block2010 by1995_block2010 by1996_block2010 by1997_block2010 by1998_block2010 by1999_block2010 incqui01_block2010 incqui03_block2010 incqui04_block2010 incqui05_block2010 incqui06_block2010 sib0_block2010 f_cumunem0_block2010 mis_f_cumunem0_block2010 m_cumunem0_block2010 mis_m_cumunem0_block2010 hhsz0_block2010 hmsz0_block2010 mis_hmsz0_block2010 f_jobexplo0_block2010 mis_f_jobexplo0_block2010 m_jobexplo0_block2010 mis_m_jobexplo0_block2010
global block2012_to_include c_age_block2012 fem_block2012 fb_block2012 misfb_block2012 c_migra_block2012 f_migra_block2012 df_akb2125_block2012 df_akb2630_block2012 df_akb3135_block2012 df_akb3640_block2012 df_akb41m_block2012 df_akbm_block2012 df_eduhs_block2012 df_eduter_block2012 df_edum_block2012 m_migra_block2012 dm_akb2125_block2012 dm_akb2630_block2012 dm_akb3135_block2012 dm_akb3640_block2012 dm_akb41m_block2012 dm_akbm_block2012 dm_eduhs_block2012 dm_eduter_block2012 dm_edum_block2012 beager_block2012 sy2002_block2012 sy2006_block2012 sy2008_block2012 sy2010_block2012 sy2012_block2012 sy2014_block2012 sy2016_block2012 sy2018_block2012 by1984_block2012 by1985_block2012 by1986_block2012 by1987_block2012 by1988_block2012 by1989_block2012 by1990_block2012 by1991_block2012 by1992_block2012 by1993_block2012 by1994_block2012 by1995_block2012 by1996_block2012 by1997_block2012 by1998_block2012 by1999_block2012 incqui01_block2012 incqui03_block2012 incqui04_block2012 incqui05_block2012 incqui06_block2012 sib0_block2012 f_cumunem0_block2012 mis_f_cumunem0_block2012 m_cumunem0_block2012 mis_m_cumunem0_block2012 hhsz0_block2012 hmsz0_block2012 mis_hmsz0_block2012 f_jobexplo0_block2012 mis_f_jobexplo0_block2012 m_jobexplo0_block2012 mis_m_jobexplo0_block2012
global block2014_to_include c_age_block2014 fem_block2014 fb_block2014 misfb_block2014 c_migra_block2014 f_migra_block2014 df_akb2125_block2014 df_akb2630_block2014 df_akb3135_block2014 df_akb3640_block2014 df_akb41m_block2014 df_akbm_block2014 df_eduhs_block2014 df_eduter_block2014 df_edum_block2014 m_migra_block2014 dm_akb2125_block2014 dm_akb2630_block2014 dm_akb3135_block2014 dm_akb3640_block2014 dm_akb41m_block2014 dm_akbm_block2014 dm_eduhs_block2014 dm_eduter_block2014 dm_edum_block2014 beager_block2014 sy2002_block2014 sy2006_block2014 sy2008_block2014 sy2010_block2014 sy2012_block2014 sy2014_block2014 sy2016_block2014 sy2018_block2014 by1984_block2014 by1985_block2014 by1986_block2014 by1987_block2014 by1988_block2014 by1989_block2014 by1990_block2014 by1991_block2014 by1992_block2014 by1993_block2014 by1994_block2014 by1995_block2014 by1996_block2014 by1997_block2014 by1998_block2014 by1999_block2014 incqui01_block2014 incqui03_block2014 incqui04_block2014 incqui05_block2014 incqui06_block2014 sib0_block2014 f_cumunem0_block2014 mis_f_cumunem0_block2014 m_cumunem0_block2014 mis_m_cumunem0_block2014 hhsz0_block2014 hmsz0_block2014 mis_hmsz0_block2014 f_jobexplo0_block2014 mis_f_jobexplo0_block2014 m_jobexplo0_block2014 mis_m_jobexplo0_block2014
global block2016_to_include c_age_block2016 fem_block2016 fb_block2016 misfb_block2016 c_migra_block2016 f_migra_block2016 df_akb2125_block2016 df_akb2630_block2016 df_akb3135_block2016 df_akb3640_block2016 df_akb41m_block2016 df_akbm_block2016 df_eduhs_block2016 df_eduter_block2016 df_edum_block2016 m_migra_block2016 dm_akb2125_block2016 dm_akb2630_block2016 dm_akb3135_block2016 dm_akb3640_block2016 dm_akb41m_block2016 dm_akbm_block2016 dm_eduhs_block2016 dm_eduter_block2016 dm_edum_block2016 beager_block2016 sy2002_block2016 sy2006_block2016 sy2008_block2016 sy2010_block2016 sy2012_block2016 sy2014_block2016 sy2016_block2016 sy2018_block2016 by1984_block2016 by1985_block2016 by1986_block2016 by1987_block2016 by1988_block2016 by1989_block2016 by1990_block2016 by1991_block2016 by1992_block2016 by1993_block2016 by1994_block2016 by1995_block2016 by1996_block2016 by1997_block2016 by1998_block2016 by1999_block2016 incqui01_block2016 incqui03_block2016 incqui04_block2016 incqui05_block2016 incqui06_block2016 sib0_block2016 f_cumunem0_block2016 mis_f_cumunem0_block2016 m_cumunem0_block2016 mis_m_cumunem0_block2016 hhsz0_block2016 hmsz0_block2016 mis_hmsz0_block2016 f_jobexplo0_block2016 mis_f_jobexplo0_block2016 m_jobexplo0_block2016 mis_m_jobexplo0_block2016
global block2018_to_include c_age_block2018 fem_block2018 fb_block2018 misfb_block2018 c_migra_block2018 f_migra_block2018 df_akb2125_block2018 df_akb2630_block2018 df_akb3135_block2018 df_akb3640_block2018 df_akb41m_block2018 df_akbm_block2018 df_eduhs_block2018 df_eduter_block2018 df_edum_block2018 m_migra_block2018 dm_akb2125_block2018 dm_akb2630_block2018 dm_akb3135_block2018 dm_akb3640_block2018 dm_akb41m_block2018 dm_akbm_block2018 dm_eduhs_block2018 dm_eduter_block2018 dm_edum_block2018 beager_block2018 sy2002_block2018 sy2006_block2018 sy2008_block2018 sy2010_block2018 sy2012_block2018 sy2014_block2018 sy2016_block2018 sy2018_block2018 by1984_block2018 by1985_block2018 by1986_block2018 by1987_block2018 by1988_block2018 by1989_block2018 by1990_block2018 by1991_block2018 by1992_block2018 by1993_block2018 by1994_block2018 by1995_block2018 by1996_block2018 by1997_block2018 by1998_block2018 by1999_block2018 incqui01_block2018 incqui03_block2018 incqui04_block2018 incqui05_block2018 incqui06_block2018 sib0_block2018 f_cumunem0_block2018 mis_f_cumunem0_block2018 m_cumunem0_block2018 mis_m_cumunem0_block2018 hhsz0_block2018 hmsz0_block2018 mis_hmsz0_block2018 f_jobexplo0_block2018 mis_f_jobexplo0_block2018 m_jobexplo0_block2018 mis_m_jobexplo0_block2018

*Regression
	*Store the results in the right directory
	cd "C:\Users\your_folder_path\tables\robustness\waves"
	*Set the dataset in blocks
	xtset pidkid_block syear
	set matsize 11000
	log using sanitycheck, replace t
	*0-15
	*Mental health
		xtregre2 stdmcs plant015 plant015_block2002 plant015_block2004 plant015_block2006 plant015_block2008 plant015_block2010 plant015_block2012 plant015_block2014 plant015_block2016 plant015_block2018 unempatage015 unempatage015_block2002 unempatage015_block2004 unempatage015_block2006 unempatage015_block2008 unempatage015_block2010 unempatage015_block2012 unempatage015_block2014 unempatage015_block2016 unempatage015_block2018 $blockall_to_include $block2002_to_include $block2004_to_include $block2006_to_include $block2008_to_include $block2010_to_include $block2012_to_include $block2014_to_include $block2016_to_include $block2018_to_include [aweight=ew015] if plant015!=. | plant015_block2002!=. | plant015_block2004!=. | plant015_block2006!=. | plant015_block2008!=. | plant015_block2010!=. | plant015_block2012!=. | plant015_block2014!=. | plant015_block2016!=. | plant015_block2018!=., i(pidkid_block)
		*Tests
		testparm plant015_block*
	*Physical health
		xtregre2 stdpcs plant015 plant015_block2002 plant015_block2004 plant015_block2006 plant015_block2008 plant015_block2010 plant015_block2012 plant015_block2014 plant015_block2016 plant015_block2018 unempatage015 unempatage015_block2002 unempatage015_block2004 unempatage015_block2006 unempatage015_block2008 unempatage015_block2010 unempatage015_block2012 unempatage015_block2014 unempatage015_block2016 unempatage015_block2018 $blockall_to_include $block2002_to_include $block2004_to_include $block2006_to_include $block2008_to_include $block2010_to_include $block2012_to_include $block2014_to_include $block2016_to_include $block2018_to_include [aweight=ew015] if plant015!=. | plant015_block2002!=. | plant015_block2004!=. | plant015_block2006!=. | plant015_block2008!=. | plant015_block2010!=. | plant015_block2012!=. | plant015_block2014!=. | plant015_block2016!=. | plant015_block2018!=., i(pidkid_block)
		*Tests
		testparm plant015_block*
	log close
restore
********************************************************************************

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
***APPENDIX ROBUSTNESS for: Collapsing to a cross-section (de-meaning in the time dimenstion)
**Note: Store the results in the right directory
cd "C:\Users\your_folder_path\tables\robustness\cross"
log using cross, replace t
*Age: 0-15
preserve
** Collapse the sample
collapse (mean) stdmcs stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos ew015 if plant015!=., by(pidkid)
*Mental health
	**Note: Model (3), includes job loss expectation 
	reg stdmcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=., vce(cluster pidkid)
	**Table
	outreg2 using cross_cum_stdmcs015.xls, aster e(r2_o) bdec(3) replace
*Physical health
	**Note: Model (3), includes job loss expectation 
	reg stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015] if plant015!=.,  vce(cluster pidkid)
	**Table
	outreg2 using cross_cum_stdpcs015.xls, aster e(r2_o) bdec(3) replace
restore
log close

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
***APPENDIX ROBUSTNESS for: Split sample in born before (after) 1991 
** Sample of individual born before 1991 (from 1984 to 1990)
**Note: Store the results in the right directory
cd "C:\Users\your_folder_path\tables\robustness\1991birth"

*Interact variable
preserve
gen postreu = 1 if c_birthyear>=1991
replace postreu = 0 if c_birthyear<1991
gen prereu = 1 if c_birthyear<1991
replace prereu = 0 if c_birthyear>=1991
gen plant015_91 = plant015*postreu
gen plant015_90 = plant015*prereu

*Generate list
global blockall_to_include c_age fem fb misfb c_migra f_migra df_akb2125 df_akb2630 df_akb3135 df_akb3640 df_akb41m df_akbm df_eduhs df_eduter df_edum m_migra dm_akb2125 dm_akb2630 dm_akb3135 dm_akb3640 dm_akb41m dm_akbm dm_eduhs dm_eduter dm_edum beager sy2002 sy2006 sy2008 sy2010 sy2012 sy2014 sy2016 sy2018 by1984 by1985 by1986 by1987 by1988 by1989 by1990 by1991 by1992 by1993 by1994 by1995 by1996 by1997 by1998 by1999 incqui01 incqui03 incqui04 incqui05 incqui06 sib0 f_cumunem0 mis_f_cumunem0 m_cumunem0 mis_m_cumunem0 hhsz0 hmsz0 mis_hmsz0 f_jobexplo0 mis_f_jobexplo0 m_jobexplo0 mis_m_jobexplo0

*Regression
	log using 9091, replace t
	*0-15
	*Mental health
		xtregre2 stdmcs plant015_90 plant015_91 unempatage015 $blockall_to_include [aweight=ew015] if plant015!=., i(pidkid)
		count if plant015_90==1 & e(sample)
		count if plant015_91==1 & e(sample)
		outreg2 using plant9091_cum_stdmcs015.xls, aster e(r2_o) bdec(3) replace
		*Tests
		test _coef[plant015_90]== _coef[plant015_91]
	*Physical health
		xtregre2 stdpcs plant015_90 plant015_91 unempatage015 $blockall_to_include [aweight=ew015] if plant015!=., i(pidkid)
		count if plant015_90==1 & e(sample)
		count if plant015_91==1 & e(sample)
		outreg2 using plant9091_cum_stdpcs015.xls, aster e(r2_o) bdec(3) replace
		*Tests
		test _coef[plant015_90]== _coef[plant015_91]
	log close
restore

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
***APPENDIX ROBUSTNESS for: Generic unemployment
**Note: Store the results in the right directory
cd "C:\Users\your_folder_path\tables\robustness\genunemp"

log using genunemp, replace t
***********
** Matching
ebalance unemp015 c_age fem c_migra bweger beager f_migra df_edum df_eduhs df_eduter df_akbm df_akb2125 df_akb2630 df_akb3135 df_akb3640 df_akb41m m_migra dm_edum dm_eduhs dm_eduter dm_akbm dm_akb2125 dm_akb2630 dm_akb3135 dm_akb3640 dm_akb41m fb misf $incqui $sibli $dadcumpre $momcumpre if unemp015!=., targets(2) tolerance(1) gen(ew015_unemp) keep(baltable015_unemp) rep

**************
** Regressions
**Note: Model (3), includes job loss expectation 
*0-15
	*Mental health
		xtregre2 stdmcs unemp015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015_unemp] if unemp015!=., i(pidkid)
		gen main015_unemp = 1 if e(sample)
		count if main015_unemp==1 & unemp015==1
		**Table
		outreg2 using unemp_cum_stdmcs015.xls, aster e(r2_o) bdec(3) replace
	*Physical health
		xtregre2 stdpcs unemp015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incqui $sibli $dadcumpre $momcumpre $hhsize $hmsize $dadjexlos $momjexlos [aweight=ew015_unemp] if unemp015!=., i(pidkid)
		count if main015_unemp==1 & unemp015==1
		**Table
		outreg2 using unemp_cum_stdpcs015.xls, aster e(r2_o) bdec(3) append
log close

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
***EXTRA ROBUSTNESS for: Missing values
**Note: Create the variables list for time-period average indicators
global incquiavg inc015q_2 inc015q_3 inc015q_4 inc015q_5
global sibavg sibli mis_sibli
global fcumavg f_cumula_unemp mis_f_cumula_unemp
global mcumavg m_cumula_unemp mis_m_cumula_unemp
global size homesize mis_homesize householdsize
global expecta f_expecta mis_f_expecta m_expecta mis_m_expecta

**Matching
ebalance plant015 c_age fem c_migra beager f_migra df_edum df_eduhs df_eduter df_akbm df_akb2125 df_akb2630 df_akb3135 df_akb3640 df_akb41m m_migra dm_edum dm_eduhs dm_eduter dm_akbm dm_akb2125 dm_akb2630 dm_akb3135 dm_akb3640 dm_akb41m fb misf $incquiavg $sibavg $fcumavg $mcumavg if plant015!=. & exc015!=1, targets(2) tolerance(1) gen(ew015_avg)

sum c_age fem $first $cmig f_migra $fathakb df_akb20l $fatheduc df_edulh m_migra $mothakb dm_akb20l $motheduc dm_edulh beager bweger $incquiavg inc015q_1 $sibavg $fcumavg $mcumavg [aweight=ew015_avg] if plant015==1 & ew015_avg!=., det
sum c_age fem $first $cmig f_migra $fathakb df_akb20l $fatheduc df_edulh m_migra $mothakb dm_akb20l $motheduc dm_edulh beager bweger $incquiavg inc015q_1 $sibavg $fcumavg $mcumavg if plant015==0 & ew015_avg!=., det
sum c_age fem $first $cmig f_migra $fathakb df_akb20l $fatheduc df_edulh m_migra $mothakb dm_akb20l $motheduc dm_edulh beager bweger $incquiavg inc015q_1 $sibavg $fcumavg $mcumavg [aweight=ew015_avg] if plant015==0 & ew015_avg!=., det

**Model 1, no household characteristics
xtregre2 stdmcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incquiavg $sibavg $fcumavg $mcumavg [aweight=ew015_avg] if plant015!=., i(pidkid)
xtregre2 stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incquiavg $sibavg $fcumavg $mcumavg [aweight=ew015_avg] if plant015!=., i(pidkid)

**Model 2, without job loss expectation
xtregre2 stdmcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incquiavg $sibavg $fcumavg $mcumavg $size [aweight=ew015_avg] if plant015!=., i(pidkid)
xtregre2 stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incquiavg $sibavg $fcumavg $mcumavg $size [aweight=ew015_avg] if plant015!=., i(pidkid)

**Model 3, includes job loss expectation
xtregre2 stdmcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incquiavg $sibavg $fcumavg $mcumavg $size $expecta [aweight=ew015_avg] if plant015!=., i(pidkid)
xtregre2 stdpcs plant015 unempatage015 c_age fem $first $cmig f_migra $fathakb $fatheduc m_migra $mothakb $motheduc $birthstate $surfe $birfe $incquiavg $sibavg $fcumavg $mcumavg $size $expecta [aweight=ew015_avg] if plant015!=., i(pidkid)

